#!/bin/sh
#
# calplot -- Generate plots of calibration phase for Scion HF radar data
# using riq-ionogram Version 1.2  
# T. Bullett   07Nov08 
# useage:
# calplot.sh RIQFILE TITLE
#
SIZE="800,600"
CALRG=13
# Column to receiver number mapping in the file#
Rxp1='$9'
Rxp2='$13'
Rxp3='$17'
Rxp4='$21'
Rxp5='$25'
Rxp6='$29'
Rxp7='$33'
Rxp8='$37'

Rxa1='$8'
Rxa2='$12'
Rxa3='$16'
Rxa4='$20'
Rxa5='$24'
Rxa6='$27'
Rxa7='$32'
Rxa8='$36'

RIQFILE=$1
BFN=$(basename $RIQFILE .RIQ)
DIR=$(dirname $RIQFILE) 
TMPDIR="$HOME/tmp/riq"
TITLE=$2
export GDFONTPATH=/usr/share/fonts/truetype/msttcorefonts/
#
# Output and temp files
mkdir -p $TMPDIR
TXTFILE=$DIR/$BFN"_cal.dat"
ABSIMG=$DIR/$BFN"_abs.png"
DIFIMG=$DIR/$BFN"_dif.png"
AMPIMG=$DIR/$BFN"_amp.png"
PLOTFILE=$TMPDIR/plot.gnu

echo $TXTFILE $ABSIMG $DIFIMG $AMPIMG 

# Use the riq-ionogram program to extract the plot file from the
# raw data file.  Many user-maintained options here!
# This is a long process; do not repeat if alredy done
if [ ! -f $TXTFILE  ] ; then 
   riq_ionogram  -X -s -G $CALRG -n2 100000  $RIQFILE > $TXTFILE
fi 

cat <<EOF > $PLOTFILE
set xrange[1.0:16.0]
set xtics 1 
set mxtics 10 
set title "$BFN  $TITLE"
set key outside
set ytics 90
set mytics 6 
set yrange[-180:180] 
set xlabel "Frequency [MHz]"
set ylabel 'Absolute Phase [deg]'
set grid
set pointsize 0.2  
set term png font arial 16  size $SIZE  crop 
set output "$ABSIMG"
plot "$TXTFILE" using 5:($Rxp1) title "Rx1" with points 1 ,\
      ""        using 5:($Rxp2) title "Rx2" with points 2 ,\
      ""        using 5:($Rxp3) title "Rx3" with points 3 ,\
      ""        using 5:($Rxp4) title "Rx4" with points 4 ,\
      ""        using 5:($Rxp5) title "Rx5" with points 5 ,\
      ""        using 5:($Rxp6) title "Rx6" with points 6 ,\
      ""        using 5:($Rxp7) title "Rx7" with points 7 ,\
      ""        using 5:($Rxp8) title "Rx8" with points 8 

set output "$DIFIMG"
set yrange [-20:20]
set ytics 5
set mytics 5
set ylabel 'Relative Phase [deg]'
plot "$TXTFILE" using 5:($Rxp2-$Rxp1) title "Rx2-Rx1" with points 1 ,\
      ""        using 5:($Rxp3-$Rxp1) title "Rx3-Rx1" with points 2 ,\
      ""        using 5:($Rxp4-$Rxp1) title "Rx4-Rx1" with points 3 ,\
      ""        using 5:($Rxp5-$Rxp1) title "Rx5-Rx1" with points 4 ,\
      ""        using 5:($Rxp6-$Rxp1) title "Rx6-Rx1" with points 5 ,\
      ""        using 5:($Rxp7-$Rxp1) title "Rx7-Rx1" with points 6 ,\
      ""        using 5:($Rxp8-$Rxp1) title "Rx8-Rx1" with points 7 
set ylabel 'Amplitude [dB]'
set yrange [0:80]
set ytics 10
set mytics 10
set output "$AMPIMG"
plot "$TXTFILE" using 5:($Rxa1) title "Rx1" with points 1 ,\
      ""        using 5:($Rxa2) title "Rx2" with points 2 ,\
      ""        using 5:($Rxa3) title "Rx3" with points 3 ,\
      ""        using 5:($Rxa4) title "Rx4" with points 4 ,\
      ""        using 5:($Rxa5) title "Rx5" with points 5 ,\
      ""        using 5:($Rxa6) title "Rx6" with points 6 ,\
      ""        using 5:($Rxa7) title "Rx7" with points 7 ,\
      ""        using 5:($Rxa8) title "Rx8" with points 8 


set output
exit

EOF

gnuplot $PLOTFILE
rm -f $PLOTFILE
exit 0
