#define VERSION 1.10		// update version
#define MAGIC 0x00524951	// from "null""RIQ"
#define SYSREF 80000000		// system clock reference, MHz
#define PATH   64		// path name length for various files
#define USER   128		// user defined area, each substructure
#define RXANTMX 32		// maximum receive antenna count per station
#define FREQMX 8192		// maximum number of base frequencies (not total frequencies)
#define BAUDMX 1024		// maximum baud count in data- and cal waveform strings
#define PULSEMX 256		// maximum pulseset element count
#define QUIETMX 64		// maximum number of quiet bands
#define MEMMX 24320		// maximum size OCRAM


typedef struct					// sct...
{
   long int           magic;			// magic number for VIPIR 
   float              struct_version;		// per #define above	
   long int           start_year;		// start time of ionogram
   long int           start_daynumber;		// start time of ionogram
   long int           start_month;		// start time of ionogram
   long int           start_day;		// start time of ionogram
   long int           start_hour;		// start time of ionogram
   long int           start_minute;		// start time of ionogram
   long int           start_second;		// start time of ionogram
   unsigned long int  start_epoch;		// start time of ionogram
   char               readme[128];		// information or operator comments
   long int           sounding_table_size;	// bytes in sounder configuration structure (this file)
   long int           decimation_method;	// if processed, 0 = no process
   float              decimation_threshold;	// if processed
   long int           pulse_table_size;         // bytes in pulse configuration structure
   long int           raw_data_size;		// bytes in raw data block (one PRI)	   
   char               user[128];		// user defined (spare)


   struct					// sct.station...
   {
      char       file_id[PATH];			// name of station settings file
      char       ursi[8];			// station URSI designation (input)
      char       rx_name[32];			// station name (input)
      float      rx_latitude;			// array reference latitude deg (input)
      float      rx_longitude;			// array reference longitude deg (input)
      float      rx_altitude;			// array reference altitude m (input)
      long int   rx_count;			// antennas at station (input, up to RXANTMX)
      char       rx_antenna_type[RXANTMX][32];	// antenna NAME text descriptors (input)
      float      rx_position[RXANTMX][3];	// antenna placement x, y, z (input)
      float      rx_direction[RXANTMX][3];	// antenna element direction (input)
      float      rx_height[RXANTMX];		// antenna height above reference ground m (input)
      float      rx_cable_length[RXANTMX];	// physical length of receive cables (input)
      float      frontend_atten;		// frontend attenuator setting (input)
      char       tx_name[32];			// station name (input)
      float      tx_latitude;			// transmit antenna latitude deg (input)
      float      tx_longitude;			// transmit antenna longitude deg (input)
      float      tx_altitude;			// transmit antenna altitude m (input)
      char       tx_antenna_type[32];		// antenna NAME descriptors (input)
      float      tx_vector[3];			// antenna vector (input)
      float      tx_height;			// antenna height above reference ground m (input)
      float      tx_cable_length;		// physical length of receive cables (input)
      long int   drive_band_count;		// number of blocked bands (derived)
      float      drive_band_bounds[QUIETMX][2];	// antenna drive bands (input)
      float      drive_band_atten[QUIETMX];	// antenna drive atteunuation in dB (input)
      long int   rf_control;                    // -1 = none, 0 = drive/quiet, 1 = full, 2 = only quiet, 3 = only atten
      char       ref_type[32];		        // OCXO or bistatic PLO (input)
      char       clock_type[32];		// NTP, GPSD, etc. (input)
      char       user[128];			// user defined (spare)
   } station;

   struct					// sct.timing....
   {
      char       file_id[PATH];			// name of time settings file
      float      pri;				// PRI period us (input)
      long int   pri_count;         		// total number of PRIs in ionogram (dervied)
      long int   pri_repeats;			// repeat count for each PRI (input)		
      float      holdoff;			// time between GPS 1 pps and start (fixed)
      long int   gate_count;			// number of gates, adjusted up for USB blocks (adjusted)
      float      gate_start;			// start gate placement us, adjusted (adjusted)
      float      gate_end;			// end gate placement us, adjusted (adjusted)
      float      gate_step; 			// range delta us (derived)         
      float      data_start;			// data pulse range placement start us (input)
      float      data_width;			// data pulse baud width us (input)
      long int   data_baud_count;		// data pulse baud count (input)
      char       data_wave_file[PATH];		// alternative baud pattern file name	  
      float      data_baud[BAUDMX][2];		// data waveform baud pattern  amp, phase (input or from file)	  
      long int   data_pairs;			// number of IQ pairs in waveform memory (derived)
      float      cal_start;			// cal range placement start us (input)
      float      cal_width;			// cal pulse baud width us (input)
      long int   cal_baud_count;		// data pulse baud count (input)
      char       cal_wave_file[PATH];		// alternative baud pattern file name	  
      float      cal_baud[BAUDMX][2];		// calibration waveform baud pattern amp, phase (input or from file)
      long int   cal_pairs;			// number of IQ pairs in waveform (derived)
      char       user[128];			// user defined (spare)
   } timing;


   struct					//sct.frequency...
   {   
      char       file_id[PATH];			// name of frequency settings file (input)
      float      base_start;			// start frequency for log or linear (input)
      float      base_end;			// end frequency for log or linear (input)
      long int   base_steps;			// computed for log, linear or from table read (derived)
      long int   tune_type;		        // 0 = fixed, 1 = log, 2 = linear, 3 = table 
      float      base_table[FREQMX];		// base frequencies pre-pulseset, and action (derived or loaded) 
      float      linear_step;			// currently in kHz (input)
      float      log_step; 			// currently in percent (input)
      char       freq_table_id[PATH]; 		// manual tuning table name (input)
      long int   tune_steps; 			// all frequencies pre-ramp repeats (derived)	 
      long int   pulse_count;			// pulse set (input)		
      long int   pulse_pattern[PULSEMX];	// pulse set (input)	
      float      pulse_offset;			// pulse set offset kHz (input)		
      long int   ramp_steps;			// pulse set count before repeat (input)		
      long int   ramp_repeats;			// repeat count of pulse set steps (nput)
      float      drive_table[FREQMX];		// base frequencies attenuation/silent table (derived) 
      char       user[128];			// user defined (spare)
   } frequency;

   struct                               	// sct.receiver...
   {
      char        file_id[PATH]; 		// name of DDC settings file	
      long int    rx_chan; 			// number of channels being used (input)	
      long int    rx_map[16]; 			// channel-to-antenna mapping (input)			
      long int 	  word_format;		        // 0 = big endian fixed, 1 = little endian, 2 = float (input) 
      long int    cic2_dec;			// DDC filter block (input) 
      long int    cic2_interp;			// DDC filter block (input) 
      long int    cic2_scale;			// DDC filter block (input) 
      long int    cic5_dec;			// DDC filter block (input) 
      long int    cic5_scale;			// DDC filter block (input) 
      char        rcf_type[32];		        // text descriptor of FIR filter block (input)  
      long int    rcf_dec;			// decimation factor for FIR filter block (input) 
      long int    rcf_taps;			// number of taps in FIR filter block (input)
      long int    coefficients[160];		// FIR filter coefficients (input)
      float       analog_delay;                 // analog delay of receiver, us
      char        user[128];			// user defined (spare)
   } receiver;

   struct					// sct.exciter...
   {
      char        file_id[PATH]; 		// name of DDC settings file	
      long int    cic_scale;			// DUC filter block (input) 
      long int    cic2_dec;			// DUC filter block (input) 
      long int    cic2_interp;			// DUC filter block (input) 
      long int    cic5_interp;			// DUC filter block (input) 
      char        rcf_type[32];		        // text descriptor of FIR filter block (input)  
      long int    rcf_taps;			// number of taps in FIR filter block (input)
      long int    rcf_taps_phase;		// number of taps in FIR filter block (input)
      long int    coefficients[256];		// FIR filter coefficients (input)
      float       analog_delay;                 // analog delay of exciter, us
      char        user[128];			// user defined (spare)
     } exciter;
   struct					//sct.monitor...
   {   
      long int    balun_currents[8]; 		// as read prior to ionogram
      long int    balun_status[8];		// as read prior to ionogram
      long int    front_end_status[8];		// as read prior to ionogram  
      long int    receiver_status[8];		// as read prior to ionogram 
      long int    exciter_status[2];		// as read prior to ionogram
      char        user[512];			// user defined (spare)
   } monitor;

} SCT;
