SUBROUTINE InitIonogram(SCT,URSICODE,RANGE0,  Ionogram)
!
! Initialize the Ionogram structure using values in the VIPIR SCT
!
! Terry Bullett
! University of Colorado Boulder
!
! 14Feb09
!
! License: Public Domain
!
! "Knowledge, Sir, should be free to all"  -- Harry Mudd
!
!
IMPLICIT NONE
INCLUDE 'sct.f90'      ! SCT
INCLUDE 'ionogram.f90' ! Processed ionogram structure
!
! Passed Variables
TYPE(SCTtype),INTENT(IN) :: SCT
CHARACTER(LEN=5),INTENT(IN):: URSICODE
REAL,INTENT(IN)::RANGE0

TYPE(IonogramType),INTENT(OUT) :: Ionogram
!
! Local Varables
INTEGER:: I,SYSTIME,ENDTIME,RUNTIME,RTM,RTS
INTEGER,DIMENSION(9)::TIMEVALUES
REAL::GateRangeStep,COVERAGE
REAL,PARAMETER :: c=299792458.0 
REAL,PARAMETER :: km_per_ns = 0.5 * c / (1.0E+3*1.0E+9)  ! kilometers per nanosecond
!
! Functions
REAL:: RangeCal    ! Determines the RANGE0 value based on manual calibrations
!
! Station
Ionogram%SCT=SCT
! URSI Code
IF (LEN_TRIM(URSICODE).GT.0) THEN
   Ionogram%URSICODE=URSICODE
ELSE
   Ionogram%URSICODE=SCT%station%ursi_id(1:5)
ENDIF
! Range Gate Cal
IF (RANGE0.EQ.-9999.0) THEN
   Ionogram%RANGE0=RangeCal(Ionogram%URSICODE,Ionogram%EpochTime)
ELSE
   Ionogram%RANGE0=RANGE0
ENDIF
! Depricated 29Sep10 
!Ionogram%Station=StationName(Ionogram%URSICODE)
! 
! Time
Ionogram%Year=SCT%start_year
Ionogram%DayNumber=SCT%start_daynumber
Ionogram%Month=SCT%start_month
Ionogram%Day=SCT%start_day
Ionogram%Hour=SCT%start_hour
Ionogram%Minute=SCT%start_minute
Ionogram%Second=SCT%start_second 
Ionogram%EpochTime=SCT%start_epoch
!
! Location
Ionogram%Latitude = SCT%Station%rx_latitude
Ionogram%Longitude= SCT%Station%rx_longitude
Ionogram%Altitude = SCT%Station%rx_altitude
!
! Range gates
Ionogram%PRI=SCT%Timing%pri
Ionogram%RangeGateOffset=SCT%Timing%range_gate_offset
Ionogram%GateCount=SCT%Timing%gate_count
Ionogram%NRANGE=Ionogram%GateCount
Ionogram%GateStart=SCT%Timing%gate_start
Ionogram%GateEnd=SCT%Timing%gate_end
Ionogram%GateStep=SCT%timing%gate_step
GateRangeStep=1000.0*SCT%timing%gate_step*km_per_ns
Ionogram%Range=0.0
DO I=1,Ionogram%NRANGE
   Ionogram%Range(I) = Ionogram%RANGE0 + REAL(I)*GateRangeStep
ENDDO

! Frequency Values
Ionogram%FreqStart=SCT%Frequency%base_start
Ionogram%FreqEnd=SCT%Frequency%base_end
Ionogram%FreqSteps=SCT%Frequency%base_steps
Ionogram%NFREQ=SCT%Frequency%base_steps
Ionogram%TuneType=SCT%Frequency%tune_type 
Ionogram%LinearStep=SCT%Frequency%linear_step
Ionogram%LogStep=SCT%Frequency%log_step
Ionogram%Frequency=0.0
DO I=1,Ionogram%NFREQ
   Ionogram%Frequency(I) = SCT%Frequency%base_table(I) 
ENDDO
!
! Transmitter Drive Level
Ionogram%TxDrive=0
DO I=1,Ionogram%NFREQ
   Ionogram%TxDrive(I) = SCT%Frequency%drive_table(I)
ENDDO
!
! Doppler default
Ionogram%NDOPP=1 
!
! Determine which ionogram datasets are in the files
Ionogram%HasTotalPower=1
Ionogram%HasOModePower=1
Ionogram%HasXModePower=1
Ionogram%HasVLoS=0
Ionogram%HasDoppler=0        ! Need allocatable arrays before this can be tested
Ionogram%HasSPGR=0
Ionogram%HasZenith=0
Ionogram%HasAzimuth=0
Ionogram%HasCoherence=0

! Set the NetCDF attributes
Ionogram%Format_Version="1.10"
Ionogram%NamingAuthority="gov.noaa.ngdc"
Ionogram%MetadataLink="http://www.ngdc.noaa.gov/ionosonde/documentation/"
Ionogram%Title="Ionosonde Data"
Ionogram%Experiment="Routine Observations"
Ionogram%Instrument="Vertical Incidence Pulsed Ionospheric Radar"
Ionogram%CdmDataType="Station"
Ionogram%ProcessingLevel="Power Average"
Ionogram%Keywords="IONOSONDE RADAR"
Ionogram%KeywordsVocabulary="http://gcmd.gsfc.nasa.gov/Resources/valids/archives/GCMD_Instrument_Keywords.pdf"
Ionogram%StandardNameVocabulary="CF-1.0"
Ionogram%MagneticModel="IGRF 10"
Ionogram%Summary="This file contains ionogram data consisting of quantities computed from raw data as a "//&
         "function of independent variables of Virtual Range (time of flight) vs Frequency of operation. "//&
         " Quantities include, at a minimum, received signal strength."
Ionogram%Comment=""
!
!
IF ((SCT%Frequency%pulse_count.EQ.8).AND.(SCT%Frequency%ramp_steps.EQ.4).AND.(SCT%Frequency%ramp_repeats.EQ.4)) THEN 
   Ionogram%Mode="Dynasonde21 B-mode"
ELSE IF ((SCT%Frequency%ramp_steps.EQ.1).AND.(SCT%Frequency%ramp_repeats.EQ.1)) THEN
   Ionogram%Mode="Fast Sweep Mode"
ELSE IF ((SCT%Frequency%pulse_count.GE.32).AND.(SCT%Frequency%ramp_steps.EQ.1).AND.(SCT%Frequency%ramp_repeats.EQ.1)) THEN
   Ionogram%Mode="Sweep Frequency Interferometer"
ELSE
   Ionogram%Mode="Research Mode"
ENDIF
!
Ionogram%Project="Global Ionospheric Specification and Forecast"
Ionogram%Acknowledgment="Archived by NGDC"
Ionogram%ContributorName="Terry Bullett"
Ionogram%ContributorRole="raw data reduction software"
!
IF (Ionogram%URSICODE.EQ.'AA109') THEN
   Ionogram%Station="Addis Ababa"
   Ionogram%MagLat=2.19
   Ionogram%MagLon=355.1
   Ionogram%GyroFreq=0.85
   Ionogram%MagDip=0.61
   Ionogram%CreatorName="Gizaw Mengistu"
   Ionogram%Institution="Addis Ababa University"
   Ionogram%CreatorEmail="gizaw_mengistu@gmx.net"
   Ionogram%CreatorUrl="http://www.ngdc.noaa.gov/stp/"
   Ionogram%PublisherName="NOAA/NGDC"
   Ionogram%PublisherEmail="ionosonde@noaa.gov"
   Ionogram%PublisherUrl="http://www.ngdc.noaa.gov/stp/"
   Ionogram%License="Public Domain"
ELSEIF (Ionogram%URSICODE.EQ.'BD840') THEN
   Ionogram%Station="Boulder"
   Ionogram%MagLat=48.6
   Ionogram%MagLon=319.6
   Ionogram%GyroFreq=1.29
   Ionogram%MagDip=66.82
   Ionogram%CreatorName="Terry Bullett"
   Ionogram%Institution="NOAA National Geophysical Data Center"
   Ionogram%CreatorEmail="Terry.Bullett@noaa.gov"
   Ionogram%CreatorUrl="http://www.ngdc.noaa.gov/stp/"
   Ionogram%PublisherName="NOAA/NGDC"
   Ionogram%PublisherEmail="ionosonde@noaa.gov"
   Ionogram%PublisherUrl="http://www.ngdc.noaa.gov/stp/"
   Ionogram%License="Public Domain"
ELSEIF (Ionogram%URSICODE.EQ.'HAJ45') THEN
   Ionogram%Station="Hanscom"
   Ionogram%MagLat=51.7
   Ionogram%MagLon=7.0
   Ionogram%GyroFreq=1.4
   Ionogram%MagDip=68.0
   Ionogram%CreatorName="Cesar Valladares"
   Ionogram%Institution="Boston College"
   Ionogram%CreatorEmail="valladar@bc.ed"
   Ionogram%CreatorUrl="http://www.ngdc.noaa.gov/stp/"
   Ionogram%PublisherName="NOAA/NGDC"
   Ionogram%PublisherEmail="ionosonde@noaa.gov"
   Ionogram%PublisherUrl="http://www.ngdc.noaa.gov/stp/"
   Ionogram%License="Public Domain"
ELSEIF (Ionogram%URSICODE.EQ.'JM91J') THEN
   Ionogram%Station="Jicamarca"
   Ionogram%MagLat=2.6
   Ionogram%MagLon=355.1
   Ionogram%GyroFreq=0.63
   Ionogram%MagDip=0.51
   Ionogram%CreatorName="Jorge Chau"
   Ionogram%Institution="Jicamarca Radio Observatory"
   Ionogram%CreatorEmail="jchau@jro.igp.gob.pe"
   Ionogram%CreatorUrl="http://www.ngdc.noaa.gov/stp/"
   Ionogram%PublisherName="Jicamarca Radio Observatory"
   Ionogram%PublisherEmail="jchau@jro.igp.gob.pe"
   Ionogram%PublisherUrl="http://jicamarca.ece.cornell.edu/"
   Ionogram%License="Public Domain"
ELSEIF (Ionogram%URSICODE.EQ.'PM91J') THEN
   Ionogram%Station="Puerto Maldonado"
   Ionogram%MagLat=2.6
   Ionogram%MagLon=355.1
   Ionogram%GyroFreq=0.61
   Ionogram%MagDip=-1.66
   Ionogram%CreatorName="C. E. Valladares"
   Ionogram%Institution="Boston College"
   Ionogram%CreatorEmail="valladar@bc.edu"
   Ionogram%CreatorUrl="http://www.ngdc.noaa.gov/stp/"
   Ionogram%PublisherName="Boston College"
   Ionogram%PublisherEmail="valladar@bc.edu"
   Ionogram%PublisherUrl="http://www.bc.edu/research/isr/"
   Ionogram%License="Per NSF LISN policy"
ELSEIF (Ionogram%URSICODE.EQ.'SJJ18') THEN
   Ionogram%Station="San Juan"
   Ionogram%MagLat=48.6
   Ionogram%MagLon=319.6
   Ionogram%GyroFreq=0.92
   Ionogram%MagDip=44.44
   Ionogram%CreatorName="Terry Bullett"
   Ionogram%Institution="NOAA National Geophysical Data Center"
   Ionogram%CreatorEmail="Terry.Bullett@noaa.gov"
   Ionogram%CreatorUrl="http://www.ngdc.noaa.gov/stp/"
   Ionogram%PublisherName="NOAA/NGDC"
   Ionogram%PublisherEmail="ionosonde@noaa.gov"
   Ionogram%PublisherUrl="http://www.ngdc.noaa.gov/stp/"
   Ionogram%License="Public Domain"
ELSEIF (Ionogram%URSICODE.EQ.'WI937') THEN
   Ionogram%Station="Wallops Island"
   Ionogram%MagLat=48.0
   Ionogram%MagLon=0.8
   Ionogram%GyroFreq=1.24
   Ionogram%MagDip=65.22 
   Ionogram%CreatorName="Terry Bullett"
   Ionogram%Institution="NASA Wallops Island Flight Facility"
   Ionogram%CreatorEmail="Terry.Bullett@noaa.gov"
   Ionogram%CreatorUrl="http://www.ngdc.noaa.gov/stp/"
   Ionogram%PublisherName="NOAA/NGDC"
   Ionogram%PublisherEmail="ionosonde@noaa.gov"
   Ionogram%PublisherUrl="http://www.ngdc.noaa.gov/stp/"
   Ionogram%License="Principle Investigator Permission"
ENDIF
!
! NGDC required metadata
Ionogram%Conventions="_Coordinates"
Ionogram%MetadataConventions="UNIDATA Dataset Discovery v1.0"
! Coverage area is set to a default +/- 0.1 degree from the receiver location
! 20 to 500 km fixed altitide
COVERAGE=0.1
WRITE(Ionogram%GeospatialLatMin,100) Ionogram%Latitude  - COVERAGE
WRITE(Ionogram%GeospatialLatMax,100) Ionogram%Latitude  + COVERAGE
Ionogram%GeospatialLatUnits="degrees"
Ionogram%GeospatialLatResolution="none"
WRITE(Ionogram%GeospatialLonMin,100) Ionogram%Longitude - COVERAGE
WRITE(Ionogram%GeospatialLonMax,100) Ionogram%Longitude + COVERAGE
Ionogram%GeospatialLonUnits="degrees"
Ionogram%GeospatialLonResolution="none"
Ionogram%GeospatialVerticalMin="20"
Ionogram%GeospatialVerticalMax="500"
Ionogram%GeospatialVerticalResolution="variable"
Ionogram%GeospatialVerticalUnits="kilometers"
Ionogram%GeospatialVerticalpositive="up"

! Start and End Times
WRITE(Ionogram%TimeCoverageStart,101) Ionogram%Year,Ionogram%Month,Ionogram%Day,Ionogram%Hour,Ionogram%Minute,Ionogram%Second
RUNTIME=(Ionogram%SCT%timing%pri*Ionogram%SCT%timing%pri_count)/1000000
ENDTIME=Ionogram%EpochTime+RUNTIME
CALL GMTIME(ENDTIME, TIMEVALUES)
TIMEVALUES(6)=TIMEVALUES(6)+1900  ! Years
TIMEVALUES(5)=TIMEVALUES(5)+1     ! Months
WRITE(Ionogram%TimeCoverageEnd,101) TIMEVALUES(6),TIMEVALUES(5),TIMEVALUES(4),TIMEVALUES(3),TIMEVALUES(2),TIMEVALUES(1)
RTM=RUNTIME/60
RTS=MOD(RUNTIME,60)
WRITE(Ionogram%TimeCoverageDuration,103) RTM,RTS
Ionogram%TimeCoverageResolution="none"
!
! Timestamps.
SYSTIME=TIME()
CALL GMTIME(SYSTIME, TIMEVALUES)
TIMEVALUES(6)=TIMEVALUES(6)+1900  ! Years
TIMEVALUES(5)=TIMEVALUES(5)+1     ! Months
WRITE(Ionogram%DateCreated,101) TIMEVALUES(6),TIMEVALUES(5),TIMEVALUES(4),TIMEVALUES(3),TIMEVALUES(2),TIMEVALUES(1)
Ionogram%DateModified=Ionogram%DateCreated
Ionogram%DateIssued=Ionogram%DateCreated
!
! Identifier
WRITE(Ionogram%Identifier,102) Ionogram%URSICODE,Ionogram%Year,Ionogram%Daynumber,Ionogram%Hour,Ionogram%Minute,Ionogram%Second
!
!  Known bugs
IF (Ionogram%EpochTime .LT. 1238306400)  THEN     !   29 March 2009
   Ionogram%Comment="Probable corrupted pulset frequency vector "//TRIM(Ionogram%Comment)
ENDIF

RETURN
100 FORMAT (F10.3)
! ISO 8601 time format
101 FORMAT (I4.4,'-',I2.2,'-',I2.2,'T',I2.2,':',I2.2,':',I2.2,'Z')
102 FORMAT ('ionogram.'A5,'_',I4.4,I3.3,3I2.2)
103 FORMAT ('TM',I2.2,'S',I2.2)

END
