SUBROUTINE MPANOISE(RGT1,RGT2,NRGT,NOISEMOD,ASCAN,  AMPMIN,MINRGT,AMPMAX,MAXRGT,AMPMPA)
!
!     Calculate the Most Probable Amplitude noise value in the IONOGRAM().
!
!     Data are expected in the range of 0 to 120 and will be binned in 1 dB bins.
!     The resolution, range and number of bins is hard-coded.  Sorry.
!
!     17Sep08  Terry Bullett
!              Converted pervious F77 version to F95
!              Increased resolution of the PDF.  Most noise is +/- 5 dB
!     01Mar09  TWB  Extended the noise level to be above the MPA by a level whose
!                   probability is 1/e that of the peak.  
!                   (probably should be 1/e [1/2.718]) 
!     08Mar09  TWB Included the range bin of the AMPMIN and AMPMAX values.
!                  Passed the range gate span as parameters
!     14May09  TWB Added NOISEMOD parameter.  This factor between -1. and 1. is
!                  used to determine the probability relative to the MPA of the
!                  desired noise value.  Values < 0 mean the noise is below MPA.
!                  Dissallowed MPA values of 0.  These are below receiver threshold.   
! 
!     ToDo:  Check for multi-modal distributions
!
!
IMPLICIT NONE
INTEGER,PARAMETER :: MINBIN=-200, MAXBIN=1200
!
!  Passed Parameters
INTEGER,INTENT(IN) :: RGT1,RGT2,NRGT
REAL,INTENT(IN) :: NOISEMOD
REAL,INTENT(IN),DIMENSION(NRGT):: ASCAN
REAL,INTENT(OUT) ::  AMPMIN,AMPMAX,AMPMPA
INTEGER,INTENT(OUT) :: MINRGT,MAXRGT
!
! Local Variables
REAL :: X,XMIN,XMAX,DX,NMM
INTEGER :: I,NS,NE,IX,NTOTAL,IRNG,DI
INTEGER:: PEAKVAL,PEAKCOUNT,DOWNCOUNT,NOISEVAL
INTEGER,DIMENSION(MINBIN:MAXBIN):: NX
!
XMIN =   0.0
XMAX = 120.0
DX =   1.0
!
! Determine the bin #'s for the limits
NS = INT(XMIN/DX)
NE = INT(XMAX/DX)
!
!
! Place the counts in the arrays
!
NTOTAL=0
I=0
NX=0
!
AMPMIN =  1.0E30
AMPMAX = -1.0E30
DO IRNG = RGT1, RGT2
   X=ASCAN(IRNG)
   IF (X.GT.AMPMAX) THEN
      AMPMAX=X
      MAXRGT=IRNG
   ENDIF
   IF (X.LT.AMPMIN) THEN
      AMPMIN=X
      MINRGT=IRNG
   ENDIF 
   IX = NINT(X/DX)
!  Ignore non-positive values
   IF (IX.GT.0) THEN
      IX = MAX(MIN(IX,NE),NS)
      NX(IX) = NX(IX) + 1
      NTOTAL = NTOTAL + 1
   ENDIF
ENDDO  ! Range Gates
!
! Find the MPA in the NX() counts array
PEAKVAL = 0
PEAKCOUNT = 0
DO I = NS,NE
  IF (NX(I).GT.PEAKCOUNT) THEN
     PEAKCOUNT = NX(I)
     PEAKVAL = I
   ENDIF
ENDDO

! Determine the value above (or below if NOISEMOD is negative) the peak where 
! the count has dropped to NOISEMOD of its peak value
!
NMM=MIN(1.0, ABS(NOISEMOD))
NOISEVAL=PEAKVAL
DOWNCOUNT = NINT(REAL(PEAKCOUNT)*NMM)
I = PEAKVAL
DI=NINT(SIGN(1.0, NOISEMOD))
DO WHILE ((NX(I).GT.DOWNCOUNT).AND.(I.LT.NE).AND.(I.GT.NS))
   I = I + DI
ENDDO   
NOISEVAL=I
AMPMPA = REAL(NOISEVAL)*DX
!
! Debug:  Output the noise PDF's 
!open(32,FILE='pdf.dat',FORM='FORMATTED',ACCESS='APPEND') 
!write(32,*) '# mpanoise= ',AMPMPA, 'mpa= ',REAL(PEAKVAL)*DX,' noisemod= ',NOISEMOD
!!!write(32,'(F10.3)' ) (ASCAN(I),I=1,RGTN)
!write(32,'(I5,F8.1,I5)')  ( I,XMIN+DX*I,NX(I),I=NS,NE)
!write(32,*)
!close(32)

RETURN
END


