PROGRAM NGI2RDF
!
! Fortran90 program to convert VIPIR NetCDF format gridded ionogram files
! .NGI into RDF format ionograms (INGV format)
!
!  30 March 2009
!  T. Bullett   CIRES
!  M. Pezzopane INGV
!  C. Scotto    INGV
!
!
IMPLICIT NONE
!
INCLUDE 'sct.f90'
INCLUDE 'ionogram.f90'
!
!
TYPE(IonogramType):: Ionogram
REAL,PARAMETER :: VERSION=0.10
REAL,PARAMETER :: c=299792458.0
CHARACTER(197) :: RDFHeader 
INTEGER :: IRNG,IFRQ,NumAve,NFREQ,LT
! MAXFRQ and MAXRNG defined in ionogram.f90 
INTEGER (KIND=1),DIMENSION(MAXRNG,MAXFRQ) :: RDFOpower, RDFXPower
REAL :: DFRQ,DRNG,MagLat,MagLon,GyroFreq,MagDip,FreqStart,FreqEnd,Longitude
CHARACTER(2)  :: OX
CHARACTER(6)  :: C1 
CHARACTER(47) :: C2 
CHARACTER(12) :: RDFNAME
CHARACTER(23) :: OUTFILE
! 
! For command line parsing
INTEGER :: K,NA
LOGICAL :: SKIP=.FALSE., INFOK=.FALSE. 
CHARACTER(120) :: INFILE,CLP
!
RDFOpower=0
RDFXpower=0
!
! Read the command line for arguments
K = IARGC() 
! Filename must exist
IF (K.LT.1) THEN
   WRITE(0,*) "ngi2rdf-> ERROR: Input file must be specified"
   CALL EXIT(-1)
RETURN
ENDIF
! Parse the command line.
DO NA = 1, K
   CALL GETARG(NA,CLP)
   IF (CLP.EQ.'-h') THEN
      WRITE(*,*)' useage: ngi2rdf filename'
      WRITE(*,*)' '
      WRITE(*,'(A,F8.3)') 'Version: ',VERSION
      WRITE(*,*)'Convert VIPIR netCDF ionograms into INGV RDF format'
      WRITE(*,*)' '
      WRITE(*,*)' Filename must be provided on the command line.'
      RETURN
   ELSE IF (SKIP) THEN
      SKIP=.FALSE.
   ELSE
!    This is the input file name
     INFILE=CLP
   ENDIF
ENDDO

!     Check if input file exists
INQUIRE(FILE=INFILE,EXIST=INFOK)
IF (.NOT.INFOK) THEN
   WRITE(0,*) ' ngi2rdf - error - Missing input file'
   CALL EXIT(-1)
ENDIF


CALL Read_netCDF3(INFILE,   Ionogram)

!WRITE(OUTFILE,102) Ionogram%URSICODE ,Ionogram%Year,Ionogram%Daynumber, Ionogram%Hour,Ionogram%Minute,Ionogram%Second 
!102 FORMAT (A5,'_',I4.4,I3.3,3I2.2,'.RDF')
! Scaling program have trouble with seconds in the filename
WRITE(OUTFILE,102) Ionogram%URSICODE ,Ionogram%Year,Ionogram%Daynumber,Ionogram%Hour,Ionogram%Minute 
102 FORMAT (A5,'_',I4.4,I3.3,2I2.2,'.RDF')


IF (Ionogram%TuneType .EQ. 1) THEN
!  Log Step Tuning
   DFRQ=1.0+Ionogram%LogStep/100.0
ELSEIF (Ionogram%TuneType .EQ. 2) THEN
!  Linear Step Tuning
   DFRQ=Ionogram%LogStep
ELSE
   WRITE(0,*)  'ngi2rdf - ERROR - Incompatable frequency tuning scheme'
   CALL EXIT(-1)
ENDIF

DRNG=Ionogram%GateStep*c/2.0E9 

C1='VIPIR '
! Just the filename, not the path
LT=LEN_TRIM(INFILE)
C2=INFILE(LT-22:LT)
!
! Hard-Wired for Boulder, CO
MagLat=46.6
MagLon=255.
GyroFreq=1.28
MagDip=66.7
OX='  '

! ToDo  Expand the number of options at this point
NFREQ=Ionogram%NFREQ
!
! Output O-Power and X-Power.  First Range Bin is the Noise value.
IF ((Ionogram%HasOModePower.NE.0).AND.(Ionogram%HasXModePower.NE.0)) THEN
   OX='OX'
   DO IFRQ=1,Ionogram%NFREQ
      RDFOPower(1,IFRQ)=MAX(0,MIN(255,NINT(Ionogram%ONoiseLevel(IFRQ))))
      RDFXPower(1,IFRQ)=MAX(0,MIN(255,NINT(Ionogram%XNoiseLevel(IFRQ))))
      DO IRNG=2,Ionogram%NRANGE
         RDFOpower(IRNG,IFRQ)=MAX(0,MIN(255,NINT(Ionogram%OPower(IRNG,IFRQ))))
         RDFXpower(IRNG,IFRQ)=MAX(0,MIN(255,NINT(Ionogram%XPower(IRNG,IFRQ))))
      ENDDO
!dbug      WRITE(*,'(512I4)')  (RDFOpower(IRNG,IFRQ),IRNG=1,512)
   ENDDO
ELSE
   WRITE(0,*) 'ngi2rdf - ERROR - O-X mode power not present in netCDF file'
   CALL EXIT(-1)
ENDIF

WRITE(RDFNAME,101) Ionogram%Year-2000,Ionogram%DayNumber,CHAR(ICHAR('A')+Ionogram%Hour),Ionogram%Minute

FreqStart=Ionogram%FreqStart/1000.0
FreqEnd=Ionogram%Frequency(NFREQ)/1000.0
NumAve=MAX(1,MIN(99,Ionogram%NumAve(1)))
Longitude=Ionogram%Longitude
IF (Ionogram%Longitude.LT.0) Longitude=360.0+Ionogram%Longitude
WRITE(RDFHeader,100) FreqStart,FreqEnd,DFRQ,Ionogram%Range(1), &
   Ionogram%Range(Ionogram%NRANGE),DRNG,NINT(Ionogram%SCT%Station%frontend_atten),0,1,0,5000, &
   NumAve,0,C1,C2,NFREQ,OX,Ionogram%URSICODE(1:5),Ionogram%Year,Ionogram%Month, &
   Ionogram%Day,Ionogram%DayNumber,Ionogram%Hour, Ionogram%Minute, &
   Ionogram%Latitude,Longitude,MagLat,MagLon,GyroFreq,MagDip,RDFNAME,CHAR(10) 

100 FORMAT(F6.3,1X,F6.3,1X,F5.3,1X,F5.1,1X,F5.1,1X,F3.1,1X,I2.2,1X,I2.2,1X,I1.1,1X,I4.4,1X,I4.4,1X, &
           I2.2,1X,I1.1,1X,A6,1X,A47,1X,I4,1X,A2,1X,A5,1X,I4.4,1X,I2.2,1X,I2.2,1X,I3.3,1X,&
           I2.2,':',I2.2,1X,F5.1,1X,F5.1,1X,F5.1,1X,F5.1,1X,F4.2,1X,F5.1,1X,A12,A1)

101 FORMAT(I2.2,I3.3,A1,I2.2,'.RDF')

OPEN(UNIT=1, FILE=OUTFILE, ACCESS='STREAM')

WRITE(1) RDFHeader
!
IF (OX.EQ.'OX') THEN
   DO IFRQ=1,Ionogram%NFREQ
      WRITE(1) (RDFOpower(IRNG,IFRQ), IRNG=1,Ionogram%NRANGE)
      WRITE(1) (RDFXpower(IRNG,IFRQ), IRNG=1,Ionogram%NRANGE)
   ENDDO
ENDIF

CLOSE(UNIT=1)
END
