#!/bin/sh
#
# powerplot-OX -- Generate O/X/Total power plots and SNR plots for Scion HF radar data
# using read_riq Version 0.2 
# T. Bullett   17Sep08 
# useage:
# powerplot.sh RIQFILE TITLE
#
SIZE="1024,768"
RIQFILE=$1
BFN=$(basename $RIQFILE .RIQ)
DIR=$(dirname $RIQFILE) 
TMPDIR="$HOME/tmp/riq"
TITLE=$2 
export GDFONTPATH=/usr/share/fonts/truetype/msttcorefonts/
#
# Output and temp files
mkdir -p $TMPDIR
TXTFILE=$DIR/$BFN".dat"
PWRIMG=$DIR/$BFN"_PWR.png"
SNRIMG=$DIR/$BFN"_SNR.png"
OIMG=$DIR/$BFN"_O.png"
XIMG=$DIR/$BFN"_X.png"
OXIMG=$DIR/$BFN"_OX.png"

PLOTFILE=$TMPDIR/plot.gnu

echo $TXTFILE $PWRIMG $SNRIMG $OXIMG

# Use the readriq program to extract the plot file from the
# raw data file.  Many user-maintained options here!
# This is a long process; do not repeat if already done
if [ ! -f $TXTFILE  ] ; then 
   riq_ionogram  -c -bf  $RIQFILE > $TXTFILE
fi 

cat <<EOF > $PLOTFILE
set pm3d map corners2color c1
set grid 
set xrange[1.0:7.0]
set xtics 1
set mxtics 10
set ytics 100
set mytics 10 
set yrange[0.0:800.0] 
set title "$BFN  $TITLE"
set xlabel "Frequency [MHz]"
set ylabel 'Range [km]'
set size 1.0, 1.0
set cbrange [-20:60]
#set palette model HSV defined ( 0 0 1 1, 1 1 1 1 )
#set palette model HSV defined ( 0 0 1 0, 1 0 1 1, 6 0.8333 1 1, 7 0.8333 0 1)
#set palette model RGB defined ( -50 'green',-5 'black', +3 'black', 50 'red')  
set term png font arial 16  size $SIZE  crop 
set output "$PWRIMG"
splot "$TXTFILE" using 3:4:5 title "Total Power [dB]"

set output "$OXIMG"
set size 1.0, 1.0
set origin 0.0, 0.1
set multiplot
set palette maxcolors 128 
set palette model HSV functions 0.0, 1.0, gray  
# set palette model HSV functions 0.0, gray, 1.0  
set colorbox user horizontal origin 0.1, 0.12 size 0.35, 0.04 border
set cblabel "O"
set zrange [*:*]
set cbrange [0:60]
splot "$TXTFILE" using 3:4:8 title "O&X SNR [dB]"
set zrange [3:*]
# set palette model HSV functions 0.31, gray, 1.0
set palette model HSV functions 0.31, 1.0, gray 
set colorbox user horizontal origin 0.50, 0.12 size 0.35, 0.04 border
set cblabel "X"
splot "$TXTFILE" using 3:4:(\$9-\$7):10 title "" 
unset multiplot 

#
set output "$SNRIMG"
set cbrange [-50:50] 
# splot "$TXTFILE" using 3:4:6 title "SNR [dB]"
splot "$TXTFILE" using 3:4:(\$7-\$9) title "OXR [dB]"
set output
exit

EOF

gnuplot $PLOTFILE
rm -f $PLOTFILE
exit 0
