#!/bin/sh
#
# powerplot -- Generate power plots and SNR plots for Scion HF radar data
# using read_riq Version 0.2 
# T. Bullett   17Sep08 
# useage:
# powerplot.sh RIQFILE TITLE
#
SIZE="1024,768"
FRQSPAN="[1:10]"
RIQFILE=$1
BFN=$(basename $RIQFILE .RIQ)
DIR=$(dirname $RIQFILE) 
TMPDIR="$HOME/tmp/riq"
TITLE=$2
export GDFONTPATH=/usr/share/fonts/truetype/msttcorefonts/
#
# Output and temp files
mkdir -p $TMPDIR
TXTFILE=$DIR/$BFN".dat"
PWRIMG=$DIR/$BFN"_PWR.png"
SNRIMG=$DIR/$BFN"_SNR.png"
PLOTFILE=$TMPDIR/plot.gnu

echo $TXTFILE $PWRIMG $SNRIMG 

# Use the readriq program to extract the plot file from the
# raw data file.  Many user-maintained options here!
# This is a long process; do not repeat if already done
if [ ! -f $TXTFILE  ] ; then 
   riq_ionogram  -X -i -bf -m 207  $RIQFILE > $TXTFILE
fi 

cat <<EOF > $PLOTFILE
set pm3d map corners2color c1
unset grid 
set xrange $FRQSPAN
set xtics 1
set mxtics 10
set ytics 100
set mytics 10 
set yrange[0.0:800.0] 
set title "$BFN  $TITLE"
set xlabel "Frequency [MHz]"
set ylabel 'Range [km]'
set size 1.0, 1.0
set cbrange [-20:80]
set cbtics 10 
set term png font arial 16  size $SIZE  crop 
set output "$PWRIMG"
splot "$TXTFILE" using 5:6:7 title "Power [dB]"
set output "$SNRIMG"
set cbrange [0:50]
splot "$TXTFILE" using 5:6:8 title "SNR [dB]"
set output
exit

EOF

gnuplot $PLOTFILE
rm -f $PLOTFILE
exit 0
