LOGICAL FUNCTION READPRI(IU, PRI)
!
! Read a single PRI from the integer Raw IQ file and return the complex I/Q values 
!
! Return value is TRUE if there is some problem, such as EOF
!
! 16 bit integers are in the file as high byte first (Big Endian)
! An offset value is applied to each range gate to prevent a value
! of precisely 0 from getting into log() functions
!
! This routine assumes that the SCT and PCT have already been read 
! and the relevant elements loaded into the PRI structure
!
!
IMPLICIT NONE
INCLUDE 'pct.f90'
INCLUDE 'pri.f90'
!
COMPLEX,PARAMETER :: CZero=(0.0, 0.0) 
!
INTEGER :: IU,IERR,RGT,IRX
! These equivalanced arrays are used to swap the bytes in the I/Q bytes
! because these i86 systems use little endian and the data are in big endian
! In theory the TRANSFER() intrinsic can be used to do this, but it will be slower
! and the intinisic is obtuse.
!
INTEGER(KIND=2),DIMENSION(2)::IPQ
INTEGER(KIND=1),DIMENSION(4)::IBP
EQUIVALENCE (IPQ(1),IBP(1))
!
!
TYPE(PRItype) :: PRI
!
! =============================================
!
!
IERR=0
READPRI=.FALSE.
!
! Get the Ascan data
DO RGT = 1, PRI%GateCount
   DO IRX = 1, PRI%ReceiverCount
      READ(IU,IOSTAT=IERR) IBP(2),IBP(1),IBP(4),IBP(3)
      IF (IERR.NE.0) THEN
         READPRI=.TRUE.
         RETURN
      ENDIF 
      PRI%Ascan(IRX,RGT)= CMPLX(REAL(IPQ(1)),REAL(IPQ(2)))
      IF (PRI%Ascan(IRX,RGT).EQ.CZero) PRI%Ascan(IRX,RGT)= (1.0,0.0)  
!      write(*,100) RGT, PRI%RangeTable(RGT),IRX,IPQ(1),IPQ(2),PRI%Ascan(IRX,RGT)
   ENDDO
ENDDO
      
RETURN
! 100 FORMAT (I6,1X,F6.1,I3,1X,2I8,2X,2F8.1)
END FUNCTION READPRI 
