SUBROUTINE Write_netCDF3(NETCDFILE,Ionogram)
!
! Program to generate a development version of a NetCDF format data file to hold
! ionogram data computed from Raw ionogram data (RIQ for VIPIR, MMM,SBF,RSF from Digisondes, etc)
! 
! This program only generates the netCDF file using Version 3.6 standards.
!
!
!   Terry Bullett
!   University of Colorado
!   02 Feb 2009
!
! License:  Public Domain
!
! "To glorify God by exploring His universe with reverence"
!
! Version 1.10 - 29Sep10  TWB
! Updates to the format as suggested by NOAA/NGDC to add metadata and
! additional decoding of the Sounding Control Table (SCT)
!

USE netcdf
IMPLICIT NONE
INCLUDE 'sct.f90' 
INCLUDE 'ionogram.f90'
!
CHARACTER(LEN=120),INTENT(IN)::NETCDFILE 
TYPE(IonogramType),INTENT(IN):: Ionogram
!
! Local Variables
INTEGER:: I,IERR,NRANGE,NFREQ,NDOPP
INTEGER(KIND=1),DIMENSION(100000):: ByteSCT
REAL,PARAMETER:: Version=1.10
REAL,DIMENSION(2,1024) :: IQARRAY
!
! netCDF variables
INTEGER,DIMENSION(2) :: IonogramArray,BasePairArray,BaseDiffsArray,RxArray,Char032Array,DriveArray,BaudArray,HasValues
INTEGER,DIMENSION(3) :: WordFormatValues
INTEGER,DIMENSION(4) :: CoherenceArray,DopplerArray
INTEGER,DIMENSION(4) :: TuneTypeValues 
INTEGER,DIMENSION(5) :: RfControlValues 
INTEGER:: YearID,DaynumberID,MonthID,DayID,HourID,MinuteID,SecondID,EpochID,LatitudeID,LongitudeID,AltitudeID
INTEGER:: ncid,Range_sizeID,Frequency_sizeID,Doppler_sizeID,RangeValID,FrequencyValID,TimeValID,SCTversionID
INTEGER:: DIM002ID,DIM003ID,NumRxPairID,DIM008ID,DIM016ID,DIM032ID,DIM064ID,DIM128ID
INTEGER:: DIM160ID,DIM256ID,DIM512ID,DIM1024ID,DIM2048ID,DIM8192ID
INTEGER:: TxDriveID,Range0ID,RangeGateOffsetID,URSIID,StationNameID,LinearStepID,LogStepID,NumAveID
INTEGER:: PRIID,GateCountID,GateStartID,GateEndID,GateStepID,FreqStartID,FreqEndID,FreqStepsID,TuneTypeID
INTEGER:: MagLatID,MagLonID,MagDipID,GyroFreqID 
INTEGER:: HasTotalPowerID,TotalPowerID,TotalNoiseID
INTEGER:: HasOModePowerID,OModePowerID,OModeNoiseID
INTEGER:: HasXModePowerID,XModePowerID,XModeNoiseID
INTEGER:: HasVLoSID,VLoSID
INTEGER:: HasDopplerID,DopplerID,DopplerFreqID
INTEGER:: HasSPGRID,SPGRID
INTEGER:: HasZenithID,ZenithID
INTEGER:: HasAzimuthID,AzimuthID
INTEGER:: HasCoherenceID,BaselinePairsID,BaselineDiffsID,CoherenceID 
! 
! For VIPIR
INTEGER:: SCTsizeID,PCTsizeID,PRIsizeID,SCTID,MagicID,SCTReadmeID,SCTUserID,DecimationMethodID,DecimationThresholdID ! SCT
! SCT%station
INTEGER:: StationFileIdID,RxNameID,RxLatitudeID,RxLongitudeID,RxAltitudeID,RxAntennaTypeID,RxCountID
INTEGER:: RxPositionID,RxDirectionID,RxHeightID,RxCableLengthID, FrontendAttenID
INTEGER:: TxNameID,TxLatitudeID,TxLongitudeID,TxAltitudeID,TxAntennaTypeID,TxVectorID,TxHeightID,TxCableLengthID
INTEGER:: DriveBandCountID,DriveBandBoundsID,DriveBandAttenID,RfControlID,RefTypeID,ClockTypeID,StationUserID
! SCT%timing
INTEGER:: TimingFileIdID,PriCountID,IonogramCountID,HoldoffID,DataWidthID
INTEGER:: DataStartID,DataBaudCountID,DataWaveFileIdID,DataBaudID,DataPairsID,CalStartID
INTEGER:: CalWidthID,CalBaudCountID,CalWaveFileIdID,CalBaudID,CalPairsID,TimingUserID
! SCT%frequency
INTEGER:: FrequencyFileIdID,BaseStepsID,BaseTableID,FrequencyTableIdID,TuneStepsID,PulseCountID,PulsePatternID,PulseOffsetID
INTEGER:: RampStepsID,RampRepeatsID,DriveTableID,FrequencyUserID
! SCT%receiver
INTEGER:: ReceiverFileIdID,RxChanID,RxMapID,WordFormatID,RxCic2DecID,RxCic2InterpID,RxCic2ScaleID,RxCic5DecID,RxCic5ScaleID
INTEGER:: RxRcf_TypeID,RxRcfDecID,RxRcfTapsID,RxCoefficientsID,RxAnalogDelayID,ReceiverUserID
! SCT%receiver
INTEGER:: ExciterFileIdID,ExCic2ScaleID,ExCic2DecID,ExCic2InterpID,ExCic5InterpID,ExRcfTypeID,ExRcfTapsID,ExRcfTapsPhaseID
INTEGER:: ExCoefficientsID,ExAnalogDelayID,ExciterUserID
! SCT%monitor
INTEGER:: BalunCurrentsID,BalunStatusID,FrontendStatusID,ReceiverStatusID,ExciterStatusID,MonitorUserID
!
! For Digisondes
INTEGER:: PREFACEID, PREFsizeID
INTEGER:: DigisondePrefLen=77
!
! Initialize variables 
IQARRAY=0.0            
! Requires:  IonogramFile, SCT structure, 
! Map the SCT into an array of bytes for the netCDF file.  This is done through a temporary file.
ByteSCT=0
OPEN (UNIT=99, STATUS="SCRATCH",FORM="UNFORMATTED", ACCESS="STREAM")
WRITE(99) Ionogram%SCT
REWIND(99)
READ(99,IOSTAT=IERR) (ByteSCT(I),I=1,Ionogram%SCT%sounding_table_size)
CLOSE(99)
!
! Create the netCDF file. The nf90_clobber parameter tells netCDF to
! overwrite this file, if it already exists.
CALL CHECK( nf90_create(NETCDFILE, NF90_CLOBBER, ncid) )
!
! --------------------------------------------------------------------------------------------------------------------
!
! Create the dimensions
! RANGE, FREQUENCY, DOPPLER
NRANGE=Ionogram%NRANGE
NFREQ=Ionogram%NFREQ
NDOPP=Ionogram%NDOPP
CALL CHECK( nf90_def_dim(ncid, "NumRange", NRANGE, Range_sizeID)            )
CALL CHECK( nf90_def_dim(ncid, "NumFrequency", NFREQ, Frequency_sizeID) )
CALL CHECK( nf90_def_dim(ncid, "NumDoppler", NDOPP, Doppler_sizeID) )
CALL CHECK( nf90_def_dim(ncid, "DIM002", 2, DIM002ID)            )
CALL CHECK( nf90_def_dim(ncid, "DIM003", 3, DIM003ID)        )
CALL CHECK( nf90_def_dim(ncid, "NumRxPair", 4,NumRxPairID) )
CALL CHECK( nf90_def_dim(ncid, "DIM008",    8, DIM008ID) )
CALL CHECK( nf90_def_dim(ncid, "DIM016",   16, DIM016ID) )
CALL CHECK( nf90_def_dim(ncid, "DIM032",   32, DIM032ID) )
CALL CHECK( nf90_def_dim(ncid, "DIM064",   64, DIM064ID) )
CALL CHECK( nf90_def_dim(ncid, "DIM128",  128, DIM128ID) )
CALL CHECK( nf90_def_dim(ncid, "DIM160",  160, DIM160ID) )
CALL CHECK( nf90_def_dim(ncid, "DIM256",  256, DIM256ID) )
CALL CHECK( nf90_def_dim(ncid, "DIM512",  512, DIM512ID) )
CALL CHECK( nf90_def_dim(ncid, "DIM1024",1024, DIM1024ID) )
CALL CHECK( nf90_def_dim(ncid, "DIM2048",2048, DIM2048ID) )
CALL CHECK( nf90_def_dim(ncid, "DIM8192",8192, DIM8192ID) )
!
! Define Array Dimensions.
IonogramArray= (/ Range_sizeID, Frequency_sizeID/)
CoherenceArray= (/ DIM002ID, NumRxPairID, Range_sizeID, Frequency_sizeID /)
DopplerArray= (/ DIM002ID, Doppler_sizeID, Range_sizeID, Frequency_sizeID /)
BasePairArray= (/ DIM002ID, NumRxPairID /)
BaseDiffsArray= (/ DIM003ID, NumRxPairID /)
RxArray= (/ DIM003ID, DIM032ID /)
Char032Array= (/ DIM032ID, DIM032ID /)
DriveArray= (/ DIM002ID, DIM064ID /)
BaudArray= (/ DIM002ID, DIM1024ID /)
HasValues= (/ 0, 1/)
RfControlValues= (/ -1, 0, 2, 2, 3 /)
TuneTypeValues= (/ 1, 2, 3, 4 /)
WordFormatValues= (/ 1, 2, 3 /)
!
! SCT for VIPIR sounders
CALL CHECK( nf90_def_dim(ncid, "SCTsize",   Ionogram%SCT%sounding_table_size, SCTsizeID) )
CALL CHECK( nf90_def_dim(ncid, "PCTsize",   Ionogram%SCT%pulse_table_size,    PCTsizeID) )
CALL CHECK( nf90_def_dim(ncid, "PRIsize",   Ionogram%SCT%raw_data_size,       PRIsizeID) )
! Preface for Digisondes
CALL CHECK( nf90_def_dim(ncid, "PREFACEsize",DigisondePrefLen, PREFsizeID) )
!
! Other brands & Models of ionosondes setting information go here
!
! -----------------------------------------------------------------------------------------------------------------------
!
! Define Variables
! Station
CALL CHECK( nf90_def_var(ncid,"URSI",NF90_CHAR,DIM008ID,  URSIID)              )
   CALL CHECK( nf90_put_att(ncid,URSIID,  "description","URSI station code")   )
CALL CHECK( nf90_def_var(ncid,"StationName",NF90_CHAR,DIM064ID,  StationNameID)    )
   CALL CHECK( nf90_put_att(ncid,StationNameID,  "description","Station Name") )
! Time
CALL CHECK( nf90_def_var(ncid,"year",NF90_SHORT, YearID) )
   CALL CHECK( nf90_put_att(ncid,YearID,  "units","UTC") )
CALL CHECK( nf90_def_var(ncid,"daynumber",NF90_SHORT, DaynumberID) )
   CALL CHECK( nf90_put_att(ncid,DaynumberID,  "description","Day of the Year") )
   CALL CHECK( nf90_put_att(ncid,DaynumberID,  "units","UTC") )
CALL CHECK( nf90_def_var(ncid,"month",NF90_SHORT, MonthID)    )
   CALL CHECK( nf90_put_att(ncid,MonthID,  "units","UTC")     )
CALL CHECK( nf90_def_var(ncid,"day",NF90_SHORT, DayID)        )
   CALL CHECK( nf90_put_att(ncid,DayID,  "units","UTC")       )
CALL CHECK( nf90_def_var(ncid,"hour",NF90_SHORT, HourID)      )
   CALL CHECK( nf90_put_att(ncid,HourID,  "units","UTC")      ) 
CALL CHECK( nf90_def_var(ncid,"minute",NF90_SHORT, MinuteID)  )
   CALL CHECK( nf90_put_att(ncid,MinuteID,  "units","UTC")    ) 
CALL CHECK( nf90_def_var(ncid,"second",NF90_SHORT, SecondID)  )
   CALL CHECK( nf90_put_att(ncid,SecondID,  "units","UTC")    )
CALL CHECK( nf90_def_var(ncid,"epoch",NF90_INT, EpochID)      )
   CALL CHECK( nf90_put_att(ncid,EpochID,  "description","UNIX epoch time") )
   CALL CHECK( nf90_put_att(ncid,EpochID,  "units","seconds since 1970-01-01 00:00:00 UTC") )
! Sensor Location
CALL CHECK( nf90_def_var(ncid,"latitude",NF90_FLOAT, LatitudeID) )
   CALL CHECK( nf90_put_att(ncid,LatitudeID,  "description","Observation latitude") )
   CALL CHECK( nf90_put_att(ncid,LatitudeID,  "units","degrees_north") )
CALL CHECK( nf90_def_var(ncid,"longitude",NF90_FLOAT, LongitudeID) )
   CALL CHECK( nf90_put_att(ncid,LongitudeID,  "description","Observation longitude") )
   CALL CHECK( nf90_put_att(ncid,LongitudeID,  "units","degrees_east") )
CALL CHECK( nf90_def_var(ncid,"altitude",NF90_FLOAT, AltitudeID) )
   CALL CHECK( nf90_put_att(ncid, AltitudeID,  "description","Observation altitude above Mean Sea Level") )
   CALL CHECK( nf90_put_att(ncid, AltitudeID,  "units","meter") )
! Magnetic Field
CALL CHECK( nf90_def_var(ncid,"MagLat",NF90_FLOAT, MagLatID) )
   CALL CHECK( nf90_put_att(ncid,MagLatID,  "description","Station Magnetic Latitude") )
   CALL CHECK( nf90_put_att(ncid,MaglatID,  "units","degrees_north") )
CALL CHECK( nf90_def_var(ncid,"MagLon",NF90_FLOAT, MagLonID) )
   CALL CHECK( nf90_put_att(ncid,MagLonID,  "description","Station Magnetic Longitude") )
   CALL CHECK( nf90_put_att(ncid,MagLonID,  "units","degrees_east") )
CALL CHECK( nf90_def_var(ncid,"MagDip",NF90_FLOAT, MagDipID) )
   CALL CHECK( nf90_put_att(ncid,MagDipID,  "description","Station Magnetic Dip ") )
   CALL CHECK( nf90_put_att(ncid,MagDipID,  "units","degrees") )
CALL CHECK( nf90_def_var(ncid,"GyroFreq",NF90_FLOAT, GyroFreqID) )
   CALL CHECK( nf90_put_att(ncid,GyroFreqID,  "description","Station GyroFrequency at 300 km altitude") )
   CALL CHECK( nf90_put_att(ncid,GyroFreqID,  "units","megahertz") )
! Range Settings
CALL CHECK( nf90_def_var(ncid,"pri",NF90_FLOAT, PRIID) )
   CALL CHECK( nf90_put_att(ncid, PRIID,  "description","Pulse Repetition Interval") )
   CALL CHECK( nf90_put_att(ncid, PRIID,  "units","microsecond") )
CALL CHECK( nf90_def_var(ncid,"range_gate_offset",NF90_FLOAT, RangeGateOffsetID) )
   CALL CHECK( nf90_put_att(ncid, RangeGateOffsetID ,  "description","Range Gate Ofset") )
   CALL CHECK( nf90_put_att(ncid, RangeGateOffsetID,  "units","microsecond") )
CALL CHECK( nf90_def_var(ncid,"gate_count",NF90_INT, GateCountID) )
   CALL CHECK( nf90_put_att(ncid, GateCountID,  "description","Number of Range Gates") )
   CALL CHECK( nf90_put_att(ncid, GateCountID,  "units","count") )
CALL CHECK( nf90_def_var(ncid,"gate_start",NF90_FLOAT, GateStartID) )
   CALL CHECK( nf90_put_att(ncid, GateStartID,  "description","start range gate placement") )
   CALL CHECK( nf90_put_att(ncid, GateStartID,  "units","microsecond") )
CALL CHECK( nf90_def_var(ncid,"gate_end",NF90_FLOAT, GateEndID) )
   CALL CHECK( nf90_put_att(ncid, GateEndID,  "description","end range gate placement") )
   CALL CHECK( nf90_put_att(ncid, GateEndID,  "units","microsecond") )
CALL CHECK( nf90_def_var(ncid,"gate_step",NF90_FLOAT, GateStepID) )
   CALL CHECK( nf90_put_att(ncid, GateStepID,  "description","range gate spacing") )
   CALL CHECK( nf90_put_att(ncid, GateStepID,  "units","microsecond") )
CALL CHECK( nf90_def_var(ncid,"Range0",NF90_FLOAT, Range0ID) )
   CALL CHECK( nf90_put_att(ncid, Range0ID,  "description","Range of the 0th range gate") )
   CALL CHECK( nf90_put_att(ncid, Range0ID,  "units","kilometer") )
! Frequency Settings
CALL CHECK( nf90_def_var(ncid,"freq_start",NF90_FLOAT, FreqStartID) )
   CALL CHECK( nf90_put_att(ncid, FreqStartID,  "description","lower frequency") )
   CALL CHECK( nf90_put_att(ncid, FreqStartID,  "units","kilohertz") )
CALL CHECK( nf90_def_var(ncid,"freq_end",NF90_FLOAT, FreqEndID) )
   CALL CHECK( nf90_put_att(ncid, FreqEndID,  "description","upper frequency") )
   CALL CHECK( nf90_put_att(ncid, FreqEndID,  "units","kilohertz") )
CALL CHECK( nf90_def_var(ncid,"tune_type",NF90_INT, TuneTypeID) )
   CALL CHECK( nf90_put_att(ncid, TuneTypeID,  "description","tuning method") )
   CALL CHECK( nf90_put_att(ncid, TuneTypeID,  "units", "flag") )
   CALL CHECK( nf90_put_att(ncid, TuneTypeID,  "flag_values", TuneTypeValues ) )
   CALL CHECK( nf90_put_att(ncid, TuneTypeID,  "flag_meanings","1=log 2=linear 3=table 4=shuffle") )
CALL CHECK( nf90_def_var(ncid,"freq_count",NF90_FLOAT, FreqStepsID) )
   CALL CHECK( nf90_put_att(ncid, FreqStepsID,  "description","number of base frequencies") )
   CALL CHECK( nf90_put_att(ncid, FreqStepsID,  "units","count") )
CALL CHECK( nf90_def_var(ncid,"linear_step",NF90_FLOAT, LinearStepID) )
   CALL CHECK( nf90_put_att(ncid, LinearStepID,  "description","linear tuning step") )
   CALL CHECK( nf90_put_att(ncid, LinearStepID,  "units","kilohertz") )
CALL CHECK( nf90_def_var(ncid,"log_step",NF90_FLOAT, LogStepID) )
   CALL CHECK( nf90_put_att(ncid, LogStepID,  "description","logarithmic tuning step") )
   CALL CHECK( nf90_put_att(ncid, LogStepID,  "units","percent") )
!
! Define the VIPIR SCT elements
CALL CHECK( nf90_def_var(ncid, "Magic", NF90_INT, MagicID) )
   CALL CHECK( nf90_put_att(ncid,MagicID,  "description","File Identification number for RIQ raw data format") )
CALL CHECK( nf90_def_var(ncid, "SCT_version", NF90_FLOAT, SCTversionID) )
   CALL CHECK( nf90_put_att(ncid,SCTversionID,  "description","version indicator for sounding configuration table") )
CALL CHECK( nf90_def_var(ncid,"SCT_readme",NF90_CHAR,DIM128ID,  SCTReadmeID)              )
   CALL CHECK( nf90_put_att(ncid,SCTReadmeID,  "description","operator comments")   )
CALL CHECK( nf90_def_var(ncid,"SCT_user",NF90_CHAR,DIM128ID,  SCTUserID)              )
   CALL CHECK( nf90_put_att(ncid, SCTUserID,  "description","SCT user-defined field")   )
CALL CHECK( nf90_def_var(ncid,"decimation_method",NF90_INT, DecimationMethodID) )
   CALL CHECK( nf90_put_att(ncid, DecimationMethodID,  "description","decimation method") )
   CALL CHECK( nf90_put_att(ncid, DecimationMethodID,  "units", "flag") )
   CALL CHECK( nf90_put_att(ncid, DecimationMethodID,  "flag_values",  0 ) )
   CALL CHECK( nf90_put_att(ncid, DecimationMethodID,  "flag_meanings","0=raw") )
CALL CHECK( nf90_def_var(ncid, "decimation_threshold", NF90_FLOAT, DecimationThresholdID) )
   CALL CHECK( nf90_put_att(ncid,DecimationThresholdID,  "description","threshold parameter for decimation method") )
   CALL CHECK( nf90_put_att(ncid, DecimationThresholdID,  "units","dimensionless parameter") )
CALL CHECK( nf90_def_var(ncid, "station_file_id", NF90_CHAR,DIM064ID, StationFileIdID) )
   CALL CHECK( nf90_put_att(ncid,StationFileIdID,  "description","name of station settings file") )
!
! SCT%station
! SCT Receiver Station Info
CALL CHECK( nf90_def_var(ncid, "rx_name", NF90_CHAR,DIM032ID, RxNameID) )
   CALL CHECK( nf90_put_att(ncid,RxNameID,  "description","receiver station name") )
CALL CHECK( nf90_def_var(ncid,"rx_latitude",NF90_FLOAT, RxLatitudeID) )
   CALL CHECK( nf90_put_att(ncid,RxLatitudeID,  "description","receiver latitude") )
   CALL CHECK( nf90_put_att(ncid,RxLatitudeID,  "units","degrees_north") )
CALL CHECK( nf90_def_var(ncid,"rx_longitude",NF90_FLOAT, RxLongitudeID) )
   CALL CHECK( nf90_put_att(ncid,RxLongitudeID,  "description","receiver longitude") )
   CALL CHECK( nf90_put_att(ncid,RxLongitudeID,  "units","degrees_east") )
CALL CHECK( nf90_def_var(ncid,"rx_altitude",NF90_FLOAT, RxAltitudeID) )
   CALL CHECK( nf90_put_att(ncid, RxAltitudeID,  "description","receiver altitude above mean sea level") )
   CALL CHECK( nf90_put_att(ncid, RxAltitudeID,  "units","meter") )
CALL CHECK( nf90_def_var(ncid,"rx_count",NF90_INT, RxCountID) )
   CALL CHECK( nf90_put_att(ncid, RxCountID,  "description","numer of receive antennas") )
CALL CHECK( nf90_def_var(ncid, "rx_antenna_type", NF90_CHAR,Char032Array, RxAntennaTypeID) )
   CALL CHECK( nf90_put_att(ncid,RxAntennaTypeID,  "description","receive antenna type") )
CALL CHECK( nf90_def_var(ncid, "rx_position", NF90_FLOAT,RxArray, RxPositionID) )
   CALL CHECK( nf90_put_att(ncid,RxPositionID,  "description","X,Y,Z = (East,North,Up) position of receive antennas") )
   CALL CHECK( nf90_put_att(ncid,RxPositionID,  "units","meter") )
CALL CHECK( nf90_def_var(ncid, "rx_direction", NF90_FLOAT,RxArray, RxDirectionID) )
   CALL CHECK( nf90_put_att(ncid,RxDirectionID,  "description","X,Y,Z = (East,North,Up) direction of receive antennas") )
   CALL CHECK( nf90_put_att(ncid,RxDirectionID,  "units","meter") )
CALL CHECK( nf90_def_var(ncid, "rx_height", NF90_FLOAT,DIM032ID, RxHeightID) )
   CALL CHECK( nf90_put_att(ncid,RxHeightID,  "description","receive antenna height above ground") )
   CALL CHECK( nf90_put_att(ncid,RxHeightID,  "units","meter") )
CALL CHECK( nf90_def_var(ncid, "rx_cable_length", NF90_FLOAT,DIM032ID, RxCableLengthID) )
   CALL CHECK( nf90_put_att(ncid,RxCableLengthID,  "description","length of receive cables") )
   CALL CHECK( nf90_put_att(ncid,RxCableLengthID,  "units","meter") )
!
CALL CHECK( nf90_def_var(ncid,"frontend_atten",NF90_FLOAT, FrontendAttenID) )
   CALL CHECK( nf90_put_att(ncid, FrontendAttenID,  "description","attenuation of the front end chassis") )
   CALL CHECK( nf90_put_att(ncid, FrontendAttenID,  "units","decibel") )
! SCT Transmitter Info
CALL CHECK( nf90_def_var(ncid, "tx_name", NF90_CHAR,DIM032ID, TxNameID) )
   CALL CHECK( nf90_put_att(ncid,TxNameID,  "description","transmitter station name") )
CALL CHECK( nf90_def_var(ncid,"tx_latitude",NF90_FLOAT, TxLatitudeID) )
   CALL CHECK( nf90_put_att(ncid,TxLatitudeID,  "description","tramsmitter latitude") )
   CALL CHECK( nf90_put_att(ncid,TxLatitudeID,  "units","degrees_north") )
CALL CHECK( nf90_def_var(ncid,"tx_longitude",NF90_FLOAT, TxLongitudeID) )
   CALL CHECK( nf90_put_att(ncid,TxLongitudeID,  "description","transmitter longitude") )
   CALL CHECK( nf90_put_att(ncid,TxLongitudeID,  "units","degrees_east") )
CALL CHECK( nf90_def_var(ncid,"tx_altitude",NF90_FLOAT, TxAltitudeID) )
   CALL CHECK( nf90_put_att(ncid, TxAltitudeID,  "description","transmit altitude above Mean Sea Level") )
   CALL CHECK( nf90_put_att(ncid, TxAltitudeID,  "units","meter") )
CALL CHECK( nf90_def_var(ncid, "tx_antenna_type", NF90_CHAR,DIM032ID, TxAntennaTypeID) )
   CALL CHECK( nf90_put_att(ncid,TxAntennaTypeID,  "description","transmit antenna type") )
CALL CHECK( nf90_def_var(ncid, "tx_vector", NF90_FLOAT, TxVectorID) )
   CALL CHECK( nf90_put_att(ncid,TxVectorID,  "description","X,Y,Z = (East,North,Up) direction of transmit antenna") )
   CALL CHECK( nf90_put_att(ncid,TxVectorID,  "units","meter") )
CALL CHECK( nf90_def_var(ncid, "tx_height", NF90_FLOAT, TxHeightID) )
   CALL CHECK( nf90_put_att(ncid,TxHeightID,  "description","transmit antenna height above ground") )
   CALL CHECK( nf90_put_att(ncid,TxHeightID,  "units","meter") )
CALL CHECK( nf90_def_var(ncid, "tx_cable_length", NF90_FLOAT, txCableLengthID) )
   CALL CHECK( nf90_put_att(ncid,TxCableLengthID,  "description","length of transmit cable") )
   CALL CHECK( nf90_put_att(ncid,TxCableLengthID,  "units","meter") )
CALL CHECK( nf90_def_var(ncid,"drive_band_count",NF90_INT, DriveBandCountID) )
   CALL CHECK( nf90_put_att(ncid, DriveBandCountID,  "description","numer of drive bands for the transmit antenna") )
CALL CHECK( nf90_def_var(ncid,"drive_band_bounds",NF90_FLOAT,DriveArray,   DriveBandBoundsID) )
   CALL CHECK( nf90_put_att(ncid, DriveBandBoundsID,  "description","drive band boundaries") )
   CALL CHECK( nf90_put_att(ncid, DriveBandBoundsID,  "units","kilohertz") )
CALL CHECK( nf90_def_var(ncid,"drive_band_atten",NF90_FLOAT,DIM064ID,   DriveBandAttenID) )
   CALL CHECK( nf90_put_att(ncid, DriveBandAttenID,  "description","drive attenuation") )
   CALL CHECK( nf90_put_att(ncid, DriveBandAttenID,  "units","decibel") )
CALL CHECK( nf90_def_var(ncid,"rf_control",NF90_INT,   RfControlID) )
   CALL CHECK( nf90_put_att(ncid, RfControlID,  "description","transmitter control flag") )
   CALL CHECK( nf90_put_att(ncid,RfControlID,  "units", "flag") )
   CALL CHECK( nf90_put_att(ncid,RfControlID,  "flag_values", RfControlValues ) )
   CALL CHECK( nf90_put_att(ncid,RfControlID,  "flag_meanings", "-1=off 0=drive/quiet 1=full 2=only_quiet 3=only_atten" ) )
CALL CHECK( nf90_def_var(ncid, "ref_type", NF90_CHAR,DIM032ID, RefTypeID) )
   CALL CHECK( nf90_put_att(ncid,RefTypeID,  "description","type of reference oscillator") )
CALL CHECK( nf90_def_var(ncid, "clock_type", NF90_CHAR,DIM032ID, ClockTypeID) )
   CALL CHECK( nf90_put_att(ncid,ClockTypeID,  "description","source of absolute timing") )
CALL CHECK( nf90_def_var(ncid, "station_user", NF90_CHAR,DIM128ID, StationUserID) )
   CALL CHECK( nf90_put_att(ncid,StationUserID,  "description","Spare space for user-defined information") )
!
! SCT%timing
CALL CHECK( nf90_def_var(ncid, "timing_file_id", NF90_CHAR,DIM064ID, TimingFileIdID) )
   CALL CHECK( nf90_put_att(ncid, TimingFileIdID,  "description","name of timing settings file") )
! PRI defined earlier
CALL CHECK( nf90_def_var(ncid,"pri_count",NF90_INT,   PriCountID) )
   CALL CHECK( nf90_put_att(ncid, PriCountID,  "description","number of pulse repetition intervals") )
   CALL CHECK( nf90_put_att(ncid, PriCountID,  "units","count") )
CALL CHECK( nf90_def_var(ncid,"ionogram_count",NF90_INT,   IonogramCountID) )
   CALL CHECK( nf90_put_att(ncid,  IonogramCountID,  "description","number of ionogram sweeps") )
   CALL CHECK( nf90_put_att(ncid,  IonogramCountID,  "units","count") )
CALL CHECK( nf90_def_var(ncid,"holdoff",NF90_FLOAT, HoldoffID) )
   CALL CHECK( nf90_put_att(ncid, HoldoffID,  "description","time between GPS reference time and ionogram start") )
   CALL CHECK( nf90_put_att(ncid, HoldoffID,  "units","microsecond") )
! Range Gate Offset defined earlier
! Gate Count defined earlier
! Gate Start defined earlier
! Gate End defined earlier
! Gate Step defined earlier
CALL CHECK( nf90_def_var(ncid,"data_start",NF90_FLOAT, DataStartID) )
   CALL CHECK( nf90_put_att(ncid,  DataStartID,  "description","data range placement start") )
   CALL CHECK( nf90_put_att(ncid,  DataStartID,  "units","microsecond") )
CALL CHECK( nf90_def_var(ncid,"date_width",NF90_FLOAT, DataWidthID) )
   CALL CHECK( nf90_put_att(ncid,  DataWidthID,  "description","data pulse baud width") )
   CALL CHECK( nf90_put_att(ncid,  DataWidthID,  "units","microsecond") )
CALL CHECK( nf90_def_var(ncid,"data_baud_count",NF90_INT,   DataBaudCountID) )
   CALL CHECK( nf90_put_att(ncid, DataBaudCountID,  "description","data pulse baud count") )
   CALL CHECK( nf90_put_att(ncid, DataBaudCountID,  "units","count") )
CALL CHECK( nf90_def_var(ncid, "data_wave_file", NF90_CHAR,DIM064ID, DataWaveFileIdID) )
   CALL CHECK( nf90_put_att(ncid, DataWaveFileIdID,  "description","data baud pattern file name") )
CALL CHECK( nf90_def_var(ncid,"data_baud",NF90_FLOAT,BaudArray,   DataBaudID) )
   CALL CHECK( nf90_put_att(ncid,  DataBaudID,  "description","data waveform baud pattern") )
   CALL CHECK( nf90_put_att(ncid,  DataBaudID,  "units","real and imaginary values") )
CALL CHECK( nf90_def_var(ncid,"data_pairs",NF90_INT,   DataPairsID) )
   CALL CHECK( nf90_put_att(ncid,  DataPairsID,  "description","number of data I/Q values in waveform memory") )
   CALL CHECK( nf90_put_att(ncid,  DataPairsID,  "units","count") )
CALL CHECK( nf90_def_var(ncid,"cal_start",NF90_FLOAT, CalStartID) )
   CALL CHECK( nf90_put_att(ncid, CalStartID,  "description","calibration range placement start") )
   CALL CHECK( nf90_put_att(ncid, CalStartID,  "units","microsecond") )
CALL CHECK( nf90_def_var(ncid,"cal_width",NF90_FLOAT, CalWidthID) )
   CALL CHECK( nf90_put_att(ncid, CalWidthID,  "description","calibration pulse baud width") )
   CALL CHECK( nf90_put_att(ncid, CalWidthID,  "units","microsecond") )
CALL CHECK( nf90_def_var(ncid,"cal_baud_count",NF90_INT,   CalBaudCountID) )
   CALL CHECK( nf90_put_att(ncid, CalBaudCountID,  "description","calibration pulse baud count") )
   CALL CHECK( nf90_put_att(ncid, CalBaudCountID,  "units","count") )
CALL CHECK( nf90_def_var(ncid, "cal_wave_file", NF90_CHAR,DIM064ID, CalWaveFileIdID) )
   CALL CHECK( nf90_put_att(ncid, CalWaveFileIdID,  "description","calibration baud pattern file name") )
CALL CHECK( nf90_def_var(ncid,"cal_baud",NF90_FLOAT,BaudArray,   CalBaudID) )
   CALL CHECK( nf90_put_att(ncid, CalBaudID,  "description","calibration waveform baud pattern") )
   CALL CHECK( nf90_put_att(ncid, CalBaudID,  "units","real and imaginary values") )
CALL CHECK( nf90_def_var(ncid,"cal_pairs",NF90_INT,   CalPairsID) )
   CALL CHECK( nf90_put_att(ncid, CalPairsID,  "description","number of calibration I/Q values in waveform memory") )
   CALL CHECK( nf90_put_att(ncid, CalPairsID,  "units","count") )
CALL CHECK( nf90_def_var(ncid, "timing_user", NF90_CHAR,DIM128ID, TimingUserID) )
   CALL CHECK( nf90_put_att(ncid,TimingUserID,  "description","Spare space for user-defined information") )
!
! SCT%frequency
CALL CHECK( nf90_def_var(ncid, "frequency_file_id", NF90_CHAR,DIM064ID, FrequencyFileIdID) )
   CALL CHECK( nf90_put_att(ncid, FrequencyFileIdID,  "description","name of frequency settings file") )
! Base Start defined earlier
! Base End defined earlier
! Tune Type defined earlier
! Freq Count defined earlier
! Linear Step defined earlier
! Log Step defined earlier
CALL CHECK( nf90_def_var(ncid,"base_steps",NF90_INT, BaseStepsID) )
   CALL CHECK( nf90_put_att(ncid, BaseStepsID,  "description","number of base frequencies") )
   CALL CHECK( nf90_put_att(ncid, BaseStepsID,  "units","count") )
CALL CHECK( nf90_def_var(ncid,"base_table",NF90_FLOAT,DIM8192ID,  BaseTableID) )
   CALL CHECK( nf90_put_att(ncid, BaseTableID,  "description","base frequency table") )
   CALL CHECK( nf90_put_att(ncid, BaseTableID,  "units","kilohertz") )
CALL CHECK( nf90_def_var(ncid, "frequency_table_id", NF90_CHAR,DIM064ID, FrequencyTableIdID) )
   CALL CHECK( nf90_put_att(ncid, FrequencyTableIdID,  "description","manual tuning file name") )
CALL CHECK( nf90_def_var(ncid,"tune_steps",NF90_INT, TuneStepsID) )
   CALL CHECK( nf90_put_att(ncid, TuneStepsID,  "description","number of frequencies, pre-ramp repeats") )
   CALL CHECK( nf90_put_att(ncid, TuneStepsID,  "units","count") )
CALL CHECK( nf90_def_var(ncid,"pulse_count",NF90_INT, PulseCountID) )
   CALL CHECK( nf90_put_att(ncid, PulseCountID,  "description","pulset frequency vector length") )
   CALL CHECK( nf90_put_att(ncid, PulseCountID,  "units","count") )
CALL CHECK( nf90_def_var(ncid,"pulse_pattern",NF90_INT,DIM256ID,  PulsePatternID) )
   CALL CHECK( nf90_put_att(ncid, PulsePatternID,  "description","pulset frequency vector") )
   CALL CHECK( nf90_put_att(ncid, PulsePatternID,  "units","dimensionless") )
CALL CHECK( nf90_def_var(ncid,"pulse_offset",NF90_INT,DIM256ID,  PulseOffsetID) )
   CALL CHECK( nf90_put_att(ncid, PulseOffsetID,  "description","pulset frequency multiplier") )
   CALL CHECK( nf90_put_att(ncid, PulseOffsetID,  "units","kilohertz") )
CALL CHECK( nf90_def_var(ncid,"ramp_steps",NF90_INT, RampStepsID) )
   CALL CHECK( nf90_put_att(ncid,RampStepsID ,  "description","pulsets per B-mode ramp (ramp length, base freqs per B-block)") )
   CALL CHECK( nf90_put_att(ncid,RampStepsID ,  "units","count") )
CALL CHECK( nf90_def_var(ncid,"ramp_repeats",NF90_INT, RampRepeatsID) )
   CALL CHECK( nf90_put_att(ncid,RampRepeatsID ,  "description","repeat count of B-mode ramps") )
   CALL CHECK( nf90_put_att(ncid,RampRepeatsID ,  "units","count") )
CALL CHECK( nf90_def_var(ncid,"drive_table",NF90_FLOAT,DIM8192ID,  DriveTableID) )
   CALL CHECK( nf90_put_att(ncid, DriveTableID,  "description","base frequencies attenuation/silent table") )
   CALL CHECK( nf90_put_att(ncid, DriveTableID,  "units","decibels") )
CALL CHECK( nf90_def_var(ncid, "frequency_user", NF90_CHAR,DIM128ID, FrequencyUserID) )
   CALL CHECK( nf90_put_att(ncid,frequencyUserID,  "description","Spare space for user-defined information") )
!
! SCT%receiver
CALL CHECK( nf90_def_var(ncid, "receiver_file_id", NF90_CHAR,DIM064ID, ReceiverFileIdID) )
   CALL CHECK( nf90_put_att(ncid, ReceiverFileIdID,  "description","name of receiver settings file") )
CALL CHECK( nf90_def_var(ncid,"rx_chan",NF90_INT, RxChanID) )
   CALL CHECK( nf90_put_att(ncid,RxChanID,  "description","number of receivers") )
   CALL CHECK( nf90_put_att(ncid,RxChanID,  "units","count") )
CALL CHECK( nf90_def_var(ncid,"rx_map",NF90_INT,DIM016ID,  RxMapID) )
   CALL CHECK( nf90_put_att(ncid,RxMapID ,  "description","receiver to antenna mapping") )
   CALL CHECK( nf90_put_att(ncid,RxMapID ,  "units","dimensionless") )
CALL CHECK( nf90_def_var(ncid,"word_format",NF90_INT, WordFormatID) )
   CALL CHECK( nf90_put_att(ncid,WordFormatID,  "description","data word format") )
   CALL CHECK( nf90_put_att(ncid,WordFormatID,  "units", "flag") )
   CALL CHECK( nf90_put_att(ncid,WordFormatID,  "flag_values", WordFormatValues ) )
   CALL CHECK( nf90_put_att(ncid,WordFormatID,  "flag_meanings","1=bit_endian_fixed 2=little_endian_fixed 3=floating_point") )
CALL CHECK( nf90_def_var(ncid,"rx_cic2_dec",NF90_INT, RxCic2DecID) )
   CALL CHECK( nf90_put_att(ncid,RxCic2DecID,  "description","DDC filter cic2 decimation factor") )
   CALL CHECK( nf90_put_att(ncid,RxCic2DecID,  "units","dimensionless") )
CALL CHECK( nf90_def_var(ncid,"rx_cic2_interp",NF90_INT, RxCic2InterpID) )
   CALL CHECK( nf90_put_att(ncid,RxCic2InterpID,  "description","DDC filter cic2 interpolation factor") )
   CALL CHECK( nf90_put_att(ncid,RxCic2InterpID,  "units","dimensionless") )!
CALL CHECK( nf90_def_var(ncid,"rx_cic2_scale",NF90_INT, RxCic2ScaleID) )
   CALL CHECK( nf90_put_att(ncid,RxCic2ScaleID,  "description","DDC filter cic2 scale factor") )
   CALL CHECK( nf90_put_att(ncid,RxCic2ScaleID,  "units","dimensionless") )
CALL CHECK( nf90_def_var(ncid,"rx_cic5_dec",NF90_INT, RxCic5DecID) )
   CALL CHECK( nf90_put_att(ncid,RxCic5DecID,  "description","DDC filter cic5 decimation factor") )
   CALL CHECK( nf90_put_att(ncid,RxCic5DecID,  "units","dimensionless") )
CALL CHECK( nf90_def_var(ncid,"rx_cic5_scale",NF90_INT, RxCic5ScaleID) )
   CALL CHECK( nf90_put_att(ncid,RxCic5ScaleID,  "description","DDC filter cic5 scale factor") )
   CALL CHECK( nf90_put_att(ncid,RxCic5ScaleID,  "units","dimensionless") )
CALL CHECK( nf90_def_var(ncid, "rx_rcf_type", NF90_CHAR,DIM032ID, RxRcf_TypeID) )
   CALL CHECK( nf90_put_att(ncid,RxRcf_TypeID,  "description"," text descriptor of FIR filter block") )
CALL CHECK( nf90_def_var(ncid,"rx_rcf_dec",NF90_INT, RxRcfDecID) )
   CALL CHECK( nf90_put_att(ncid,RxRcfDecID,  "description","decimation factor for FIR filter block") )
   CALL CHECK( nf90_put_att(ncid,RxRcfDecID,  "units","dimensionless") )
CALL CHECK( nf90_def_var(ncid,"rx_rcf_taps",NF90_INT, RxRcfTapsID) )
   CALL CHECK( nf90_put_att(ncid,RxRcfTapsID,  "description","number of taps in FIR filter block") )
   CALL CHECK( nf90_put_att(ncid,RxRcfTapsID,  "units","count") )
CALL CHECK( nf90_def_var(ncid,"rx_coefficients",NF90_INT,DIM160ID,  RxCoefficientsID) )
   CALL CHECK( nf90_put_att(ncid,RxCoefficientsID,  "description","Receiver filter coefficients") )
   CALL CHECK( nf90_put_att(ncid,RxCoefficientsID,  "units","dimensionless") )
CALL CHECK( nf90_def_var(ncid,"rx_analog_delay",NF90_REAL,   RxAnalogDelayID) )
   CALL CHECK( nf90_put_att(ncid,RxAnalogDelayID,  "description"," analog delay of receiver") )
   CALL CHECK( nf90_put_att(ncid,RxAnalogDelayID,  "units","microsecond") )
CALL CHECK( nf90_def_var(ncid, "receiver_user", NF90_CHAR,DIM128ID, ReceiverUserID) )
   CALL CHECK( nf90_put_att(ncid,ReceiverUserID,  "description","Spare space for user-defined information") )
! SCT%exciter
CALL CHECK( nf90_def_var(ncid, "exciter_file_id", NF90_CHAR,DIM064ID, ExciterFileIdID) )
   CALL CHECK( nf90_put_att(ncid, ExciterFileIdID,  "description","name of  settings file") )
CALL CHECK( nf90_def_var(ncid,"ex_cic2_scale",NF90_INT, ExCic2ScaleID) )
   CALL CHECK( nf90_put_att(ncid,ExCic2ScaleID,  "description","DUC filter cic2 scale factor") )
   CALL CHECK( nf90_put_att(ncid,ExCic2ScaleID,  "units","dimensionless") )
CALL CHECK( nf90_def_var(ncid,"ex_cic2_dec",NF90_INT, ExCic2DecID) )
   CALL CHECK( nf90_put_att(ncid,ExCic2DecID,  "description","DUC filter cic2 decimation factor") )
   CALL CHECK( nf90_put_att(ncid,ExCic2DecID,  "units","dimensionless") )
CALL CHECK( nf90_def_var(ncid,"ex_cic2_interp",NF90_INT, ExCic2InterpID) )
   CALL CHECK( nf90_put_att(ncid,ExCic2InterpID,  "description","DUC filter cic2 interpolation factor") )
   CALL CHECK( nf90_put_att(ncid,ExCic2InterpID,  "units","dimensionless") )
CALL CHECK( nf90_def_var(ncid,"ex_cic5_interp",NF90_INT, ExCic5InterpID) )
   CALL CHECK( nf90_put_att(ncid,ExCic5InterpID,  "description","DUC filter cic5 interpolation factor") )
   CALL CHECK( nf90_put_att(ncid,ExCic5InterpID,  "units","dimensionless") )
CALL CHECK( nf90_def_var(ncid,"ex_rcf_type", NF90_CHAR,DIM032ID, ExRcfTypeID) )
   CALL CHECK( nf90_put_att(ncid,ExRcfTypeID,  "description"," text descriptor of FIR filter block") )
CALL CHECK( nf90_def_var(ncid,"ex_rcf_taps",NF90_INT, ExRcfTapsID) )
   CALL CHECK( nf90_put_att(ncid,ExRcfTapsID,  "description","number of taps in FIR filter block") )
   CALL CHECK( nf90_put_att(ncid,ExRcfTapsID,  "units","count") )
CALL CHECK( nf90_def_var(ncid,"ex_rcf_taps_phase",NF90_INT, ExRcfTapsPhaseID) )
   CALL CHECK( nf90_put_att(ncid,ExRcfTapsPhaseID,  "description","exciter phase") )
   CALL CHECK( nf90_put_att(ncid,ExRcfTapsPhaseID,  "units","dimensionless") )
CALL CHECK( nf90_def_var(ncid,"ex_coefficients",NF90_INT,DIM256ID,  ExCoefficientsID) )
   CALL CHECK( nf90_put_att(ncid,ExCoefficientsID,  "description","Exciter filter coefficients") )
   CALL CHECK( nf90_put_att(ncid,ExCoefficientsID,  "units","dimensionless") )
CALL CHECK( nf90_def_var(ncid,"ex_analog_delay",NF90_REAL,   ExAnalogDelayID) )
   CALL CHECK( nf90_put_att(ncid,ExAnalogDelayID,  "description"," analog delay of exciter") )
   CALL CHECK( nf90_put_att(ncid,ExAnalogDelayID,  "units","microsecond") )
CALL CHECK( nf90_def_var(ncid, "exciter_user", NF90_CHAR,DIM128ID, ExciterUserID) )
   CALL CHECK( nf90_put_att(ncid,frequencyUserID,  "description","Spare space for user-defined information") )
!
! SCT%monitor
CALL CHECK( nf90_def_var(ncid,"balun_currents",NF90_INT,DIM008ID,  BalunCurrentsID) )
   CALL CHECK( nf90_put_att(ncid,BalunCurrentsID,  "description","Balun chassis current monitor") )
   CALL CHECK( nf90_put_att(ncid,BalunCurrentsID,  "units","uncalibrated") )
CALL CHECK( nf90_def_var(ncid,"balun_status",NF90_INT,DIM008ID,  BalunStatusID) )
   CALL CHECK( nf90_put_att(ncid,BalunStatusID,  "description","Balun chassis status monitor") )
   CALL CHECK( nf90_put_att(ncid,BalunStatusID,  "units","uncalibrated") )
CALL CHECK( nf90_def_var(ncid,"frontend_status",NF90_INT,DIM008ID,  FrontendStatusID) )
   CALL CHECK( nf90_put_att(ncid,FrontendStatusID,  "description","Front End chassis status monitor") )
   CALL CHECK( nf90_put_att(ncid,FrontendStatusID,  "units","uncalibrated") )
CALL CHECK( nf90_def_var(ncid,"receiver_status",NF90_INT,DIM008ID,  ReceiverStatusID) )
   CALL CHECK( nf90_put_att(ncid,ReceiverStatusID,  "description","Receiver chassis status monitor") )
   CALL CHECK( nf90_put_att(ncid,ReceiverStatusID,  "units","uncalibrated") )
CALL CHECK( nf90_def_var(ncid,"exciter_status",NF90_INT,DIM008ID,  ExciterStatusID) )
   CALL CHECK( nf90_put_att(ncid,ExciterStatusID,  "description","Exciter chassis status monitor") )
   CALL CHECK( nf90_put_att(ncid,ExciterStatusID,  "units","uncalibrated") )
CALL CHECK( nf90_def_var(ncid, "monitor_user", NF90_CHAR,DIM512ID, MonitorUserID) )
   CALL CHECK( nf90_put_att(ncid,MonitorUserID,  "description","Spare space for user-defined information") )


! The raw SCT
CALL CHECK( nf90_def_var(ncid, "SCT",NF90_BYTE,SCTsizeID,  SCTID) )
   CALL CHECK( nf90_put_att(ncid,SCTID,  "description","VIPIR Sounding Configuration Table") )
   CALL CHECK( nf90_put_att(ncid,SCTID,  "units","binary_object") )
! Define the Digisonde preface 
CALL CHECK( nf90_def_var(ncid, "PREFACE",NF90_BYTE,PREFsizeID,  PREFACEID) )
   CALL CHECK( nf90_put_att(ncid,PREFACEID,  "description","Digisonde Preface") )
   CALL CHECK( nf90_put_att(ncid,PREFACEID,  "units","binary_object") )
!
!
! Define the Range, Frequency, Number, Time & Tx 1-dimensional tables
CALL CHECK( nf90_def_var(ncid,"Range",NF90_REAL,Range_sizeID, RangeValID) )
   CALL CHECK( nf90_put_att(ncid, RangeValID,"description","Radar Range") )
   CALL CHECK( nf90_put_att(ncid, RangeValID,"units","kilometer") )
! 
CALL CHECK( nf90_def_var(ncid,"Frequency",NF90_REAL,Frequency_sizeID, FrequencyValID) ) 
   CALL CHECK( nf90_put_att(ncid,FrequencyValID,  "description","Nominal Frequency") )
   CALL CHECK( nf90_put_att(ncid,FrequencyValID,  "units","kilohertz") )
!
CALL CHECK( nf90_def_var(ncid,"Time",NF90_REAL,Frequency_sizeID, TimeValID) )
   CALL CHECK( nf90_put_att(ncid,TimeValID,  "description","Nominal Observation Time, UT") )
   CALL CHECK( nf90_put_att(ncid,TimeValID,  "units","second") )
!
CALL CHECK( nf90_def_var(ncid,"TxDrive",NF90_REAL,Frequency_sizeID, TxDriveID) )
   CALL CHECK( nf90_put_att(ncid,TxDriveID,  "description","Transmitter Drive Level") )
   CALL CHECK( nf90_put_att(ncid,TxDriveID,  "units","decibel") )
!
CALL CHECK( nf90_def_var(ncid,"NumAve",NF90_INT,Frequency_sizeID, NumAveID) )
   CALL CHECK( nf90_put_att(ncid,NumAveID,  "description","Number of PRIs and Receivers included") )
   CALL CHECK( nf90_put_att(ncid,NumAveID,  "units","count") )
!
! The 2D data arrays
!
! Total Power
CALL CHECK( nf90_def_var(ncid, "Has_total_power",NF90_BYTE,  HasTotalPowerID) )
   CALL CHECK( nf90_put_att(ncid,HasTotalPowerID,  "description", "Flag indicating presence of total power data") )
   CALL CHECK( nf90_put_att(ncid,HasTotalPowerID,  "units", "flag") )
   CALL CHECK( nf90_put_att(ncid,HasTotalPowerID,  "flag_values", HasValues ) )
   CALL CHECK( nf90_put_att(ncid,HasTotalPowerID,  "flag_meanings", "0=data_absent 1=data_present") )

IF (Ionogram%HasTotalPower.NE.0) THEN
   CALL CHECK( nf90_def_var(ncid, "total_power",NF90_FLOAT,IonogramArray,  TotalPowerID) )
      CALL CHECK( nf90_put_att(ncid,TotalPowerID,  "description", "total received power") )
      CALL CHECK( nf90_put_att(ncid,TotalPowerID,  "units","decibel") )
   CALL CHECK( nf90_def_var(ncid, "total_noise",NF90_FLOAT,Frequency_sizeID,  TotalNoiseID) )
      CALL CHECK( nf90_put_att(ncid, TotalNoiseId, "description", "Total Power Noise Level") )
      CALL CHECK( nf90_put_att(ncid, TotalNoiseId, "units", "decibel") )
ENDIF
!
! Ordinary Mode Power
CALL CHECK( nf90_def_var(ncid, "Has_O-mode_power",NF90_BYTE,  HasOModePowerID) )
   CALL CHECK( nf90_put_att(ncid,HasOModePowerID,  "description", "Flag indicating presence of O-mode power data") )
   CALL CHECK( nf90_put_att(ncid,HasOModePowerID,  "units", "flag") )
   CALL CHECK( nf90_put_att(ncid,HasOModePowerID,  "flag_values", HasValues ) )
   CALL CHECK( nf90_put_att(ncid,HasOModePowerID,  "flag_meanings", "0=data_absent 1=data_present") )

IF (Ionogram%HasOModePower .NE. 0) THEN
   CALL CHECK( nf90_def_var(ncid, "O-mode_power",NF90_FLOAT,IonogramArray,  OModePowerID) )
     CALL CHECK( nf90_put_att(ncid,OModePowerID,  "description", "Ordinary mode received power") )
     CALL CHECK( nf90_put_att(ncid,OModePowerID,  "units","decibel") )
   CALL CHECK( nf90_def_var(ncid, "O-mode_noise",NF90_FLOAT,Frequency_sizeID,  OModeNoiseID) )
     CALL CHECK( nf90_put_att(ncid, OModeNoiseId, "description", "Ordinary mode Noise Level") )
     CALL CHECK( nf90_put_att(ncid, OModeNoiseId, "units", "decibel") )
ENDIF
!
! eXtraordinary Mode Power
CALL CHECK( nf90_def_var(ncid, "Has_X-mode_power",NF90_BYTE,  HasXModePowerID) )
   CALL CHECK( nf90_put_att(ncid,HasXModePowerID,  "description", "Flag indicating presence of X-mode power data") )
   CALL CHECK( nf90_put_att(ncid,HasXModePowerID,  "units", "flag") )
   CALL CHECK( nf90_put_att(ncid,HasXModePowerID,  "flag_values", HasValues ) )
   CALL CHECK( nf90_put_att(ncid,HasXModePowerID,  "flag_meanings", "0=data_absent 1=data_present") )
IF (Ionogram%HasXModePower .NE. 0) THEN
   CALL CHECK( nf90_def_var(ncid, "X-mode_power",NF90_FLOAT,IonogramArray,  XModePowerID) )
      CALL CHECK( nf90_put_att(ncid,XModePowerID,  "description", "eXtraordinary mode received power") )
      CALL CHECK( nf90_put_att(ncid,XModePowerID,  "units","decibel") )
   CALL CHECK( nf90_def_var(ncid, "X-mode_noise",NF90_FLOAT,Frequency_sizeID,  XModeNoiseID) )
     CALL CHECK( nf90_put_att(ncid, XModeNoiseId, "description", "eXtraordiary mode Noise Level") )
     CALL CHECK( nf90_put_att(ncid, XModeNoiseId, "units", "decibel") )
ENDIF
!
! LoS Velocity Data
   CALL CHECK( nf90_def_var(ncid, "Has_VLoS",NF90_BYTE,  HasVLoSID) )
     CALL CHECK( nf90_put_att(ncid,HasVLoSID,  "description", "Flag indicating presence of Line of Sight Velocity data"))
     CALL CHECK( nf90_put_att(ncid,HasVLoSID,  "units", "flag") )
     CALL CHECK( nf90_put_att(ncid,HasVLosID,  "flag_values", HasValues ) )
     CALL CHECK( nf90_put_att(ncid,HasVlosID,  "flag_meanings", "0=data_absent 1=data_present") )
IF (Ionogram%HasVLoS.NE.0) THEN
   CALL CHECK( nf90_def_var(ncid, "VLoS",NF90_FLOAT,IonogramArray,  VLoSID) )
     CALL CHECK( nf90_put_att(ncid,VLoSID,  "description", "Apparent Line of Sight Velocity") )
     CALL CHECK( nf90_put_att(ncid,VLoSID,  "units","m/s") )
ENDIF
!
! Doppler Shift Data
   CALL CHECK( nf90_def_var(ncid, "Has_Doppler",NF90_BYTE,  HasDopplerID) )
   CALL CHECK( nf90_put_att(ncid,HasDopplerID,  "description", "Flag indicating presence of Doppler data") )
   CALL CHECK( nf90_put_att(ncid,HasDopplerID,  "units", "flag") )
   CALL CHECK( nf90_put_att(ncid,HasDopplerID,  "flag_values", HasValues ) )
   CALL CHECK( nf90_put_att(ncid,HasDopplerID,  "flag_meanings", "0=data_absent 1=data_present") )
IF (Ionogram%HasDoppler.NE.0) THEN
   CALL CHECK( nf90_def_var(ncid, "DopplerFreq",NF90_FLOAT,Doppler_sizeID, DopplerFreqID)  ) 
   CALL CHECK( nf90_put_att(ncid,DopplerFreqID,  "description", "Doppler Frequency") )
   CALL CHECK( nf90_put_att(ncid,DopplerFreqID,  "units","Hz") )
   CALL CHECK( nf90_def_var(ncid, "Doppler",NF90_FLOAT,DopplerArray,  DopplerID) )
   CALL CHECK( nf90_put_att(ncid,DopplerID,  "description", "Doppler Spectrum") )
   CALL CHECK( nf90_put_att(ncid,DopplerID,  "units","Complex Spectral Amplitude") )
ENDIF
!
! Stationary Phase Group Range or Precision Group Height  
CALL CHECK( nf90_def_var(ncid, "Has_SPGR",NF90_BYTE,  HasSPGRID) )
   CALL CHECK( nf90_put_att(ncid,HasSPGRID,  "description", "Flag indicating presence of SPGR data") )
   CALL CHECK( nf90_put_att(ncid,HasSPGRID,  "units", "flag") )
   CALL CHECK( nf90_put_att(ncid,HasSPGRID,  "flag_values", HasValues ) )
   CALL CHECK( nf90_put_att(ncid,HasSPGRID,  "flag_meanings", "0=data_absent 1=data_present") )
IF (Ionogram%HasSPGR.NE.0) THEN
   CALL CHECK( nf90_def_var(ncid, "SPGR",NF90_FLOAT,IonogramArray,  SPGRID) )
   CALL CHECK( nf90_put_att(ncid,SPGRID,  "description", "Stationary Phase Group Range") )
   CALL CHECK( nf90_put_att(ncid,SPGRID,  "units","km") )
ENDIF
!
! Zenith Angle data
CALL CHECK( nf90_def_var(ncid, "Has_Zenith",NF90_BYTE,  HasZenithID) )
   CALL CHECK( nf90_put_att(ncid,HasZenithID,  "description", "Flag indicating presence of zenith angle data") )
   CALL CHECK( nf90_put_att(ncid,HasZenithID,  "units", "flag") )
   CALL CHECK( nf90_put_att(ncid,HasZenithID,  "flag_values", HasValues ) )
   CALL CHECK( nf90_put_att(ncid,HasZenithID,  "flag_meanings", "0=data_absent 1=data_present") )
IF (Ionogram%HasZenith.NE.0) THEN
   CALL CHECK( nf90_def_var(ncid, "zenith",NF90_FLOAT,IonogramArray,  ZenithID) )
     CALL CHECK( nf90_put_att(ncid,ZenithID,  "description", "zenith angle") )
     CALL CHECK( nf90_put_att(ncid,ZenithID,  "units","degree") )
ENDIF
!
! Azimuth Angle
CALL CHECK( nf90_def_var(ncid, "Has_Azimuth",NF90_BYTE,  HasAzimuthID) )
   CALL CHECK( nf90_put_att(ncid,HasAzimuthID,  "description", "Flag indicating presence of azimuth angle data") )
   CALL CHECK( nf90_put_att(ncid,HasAzimuthID,  "units", "flag") )
   CALL CHECK( nf90_put_att(ncid,HasAzimuthID,  "flag_values", HasValues ) )
   CALL CHECK( nf90_put_att(ncid,HasAzimuthID,  "flag_meanings", "0=data_absent 1=data_present") )
IF (Ionogram%HasAzimuth.NE.0) THEN
   CALL CHECK( nf90_def_var(ncid, "azimuth",NF90_FLOAT,IonogramArray,  AzimuthID) )
     CALL CHECK( nf90_put_att(ncid,AzimuthID,  "description", "azimuth angle, 0=True North, 90=True East") )
     CALL CHECK( nf90_put_att(ncid,AzimuthID,  "units","degree") )
ENDIF
!
! Coherence Arrays
CALL CHECK( nf90_def_var(ncid, "Has_Coherence",NF90_BYTE,  HasCoherenceID) )
   CALL CHECK( nf90_put_att(ncid,HasCoherenceID,  "description", "Flag indicating presence of coherence data") )
   CALL CHECK( nf90_put_att(ncid,HasCoherenceID,  "units", "flag") )
   CALL CHECK( nf90_put_att(ncid,HasCoherenceID,  "flag_values", HasValues ) )
   CALL CHECK( nf90_put_att(ncid,HasCoherenceID,  "flag_meanings", "0=data_absent 1=data_present") )

IF (Ionogram%HasCoherence.NE.0) THEN
   CALL CHECK( nf90_def_var(ncid, "baseline_pairs",NF90_SHORT,BasePairArray,  BaselinePairsID) )
     CALL CHECK( nf90_put_att(ncid,BaselinePairsID,  "description", "baseline pair elements") )
     CALL CHECK( nf90_put_att(ncid,BaselinePairsID,  "units","antenna pairs") )
   CALL CHECK( nf90_def_var(ncid, "baseline_diffs",NF90_SHORT,BaseDiffsArray,  BaselineDiffsID) )
     CALL CHECK( nf90_put_att(ncid,BaselineDiffsID,  "description", "baseline difference vectors (x,y,z)") )
     CALL CHECK( nf90_put_att(ncid,BaselineDiffsID,  "units","meter") )
   CALL CHECK( nf90_def_var(ncid, "coherence",NF90_FLOAT,CoherenceArray,  CoherenceID) )
     CALL CHECK( nf90_put_att(ncid,CoherenceID,  "description", "Complex Coherence") )
     CALL CHECK( nf90_put_att(ncid,CoherenceID,  "units","real and imaginary") )
!  Add coherence arrays here
ENDIF
!
! ----------------------------------------------------------------------------------------------------------------
!
! Global Attributes 
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "format_version", Ionogram%Format_Version ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "id", Ionogram%Identifier ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "naming_authority", Ionogram%NamingAuthority ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "Metadata_Link", Ionogram%MetadataLink ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "title", Ionogram%Title ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "station", Ionogram%Station ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "instrument", Ionogram%Instrument ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "cdm_data_type", Ionogram%CdmDataType ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "processing_level", Ionogram%ProcessingLevel ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "experiment", Ionogram%Experiment ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "date_created", Ionogram%DateCreated ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "date_modified", Ionogram%DateModified ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "date_issued", Ionogram%DateIssued ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "time_coverage_start", Ionogram%TimeCoverageStart ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "time_coverage_end", Ionogram%TimeCoverageEnd ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "time_coverage_duration", Ionogram%TimeCoverageDuration ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "time_coverage_resolution", Ionogram%TimeCoverageResolution ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "geospatial_lat_min", Ionogram%GeospatialLatMin ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "geospatial_lat_max", Ionogram%GeospatialLatMax ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "geospatial_lat_units", Ionogram%GeospatialLatUnits ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "geospatial_lat_resolution", Ionogram%GeospatialLatResolution ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "geospatial_lon_min", Ionogram%GeospatialLonMin ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "geospatial_lon_max", Ionogram%GeospatialLonMax ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "geospatial_lon_units", Ionogram%GeospatialLonUnits ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "geospatial_lon_resolution", Ionogram%GeospatialLonResolution ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "geospatial_vertical_min", Ionogram%GeospatialVerticalMin ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "geospatial_vertical_max", Ionogram%GeospatialVerticalMax ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "geospatial_vertical_units", Ionogram%GeospatialVerticalUnits ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "geospatial_vertical_resolution", Ionogram%GeospatialVerticalResolution ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "geospatial_vertical_positive", Ionogram%GeospatialVerticalPositive ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "mode", Ionogram%Mode ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "magnetic_model", Ionogram%MagneticModel) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "creator_name", Ionogram%CreatorName ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "institution", Ionogram%Institution ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "creator_email", Ionogram%CreatorEmail ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "creator_url", Ionogram%CreatorUrl ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "publisher_name", Ionogram%PublisherName ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "publisher_email", Ionogram%PublisherEmail ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "publisher_url", Ionogram%PublisherUrl ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "license", Ionogram%License ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "project", Ionogram%Project ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "acknowledgment", Ionogram%Acknowledgment ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "contributor_name", Ionogram%ContributorName ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "contributor_role", Ionogram%ContributorRole ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "Conventions", Ionogram%Conventions) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "Metadata_Conventions", Ionogram%MetadataConventions) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "keywords", Ionogram%Keywords) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "keywords_vocabulary", Ionogram%KeywordsVocabulary) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "standard_name_vocabulary", Ionogram%StandardNameVocabulary) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "summary", Ionogram%Summary ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "comment", Ionogram%Comment ) )
CALL CHECK( nf90_put_att(ncid,NF90_GLOBAL, "history", Ionogram%History) )
!
! End define mode.
CALL CHECK( nf90_enddef(ncid) )
!
!  ----------------------------------------------------------------------------------------------------------------------
!
! Transfer values from SCT & Ionogram 
!
! Station
CALL CHECK( nf90_put_var(ncid,URSIID,        Ionogram%URSICODE)  )
CALL CHECK( nf90_put_var(ncid,StationNameID, Ionogram%Station)   )
! Time
CALL CHECK( nf90_put_var(ncid,YearID,        Ionogram%Year)      )
CALL CHECK( nf90_put_var(ncid,DaynumberID,   Ionogram%DayNumber) )
CALL CHECK( nf90_put_var(ncid,MonthID,       Ionogram%Month)     )
CALL CHECK( nf90_put_var(ncid,DayID,         Ionogram%Day)       )
CALL CHECK( nf90_put_var(ncid,HourID,        Ionogram%Hour)      )
CALL CHECK( nf90_put_var(ncid,MinuteID,      Ionogram%Minute)    )
CALL CHECK( nf90_put_var(ncid,SecondID,      Ionogram%Second)    )
CALL CHECK( nf90_put_var(ncid,EpochID,       Ionogram%EpochTime) )
! Sensor Location
CALL CHECK( nf90_put_var(ncid,LatitudeID,    Ionogram%Latitude)  )
CALL CHECK( nf90_put_var(ncid,LongitudeID,   Ionogram%Longitude) )
CALL CHECK( nf90_put_var(ncid,AltitudeID,    Ionogram%Altitude)  )
! Magnetic Field
CALL CHECK( nf90_put_var(ncid,MagLatID,      Ionogram%MagLat)   )
CALL CHECK( nf90_put_var(ncid,MagLonID,      Ionogram%MagLon)   )
CALL CHECK( nf90_put_var(ncid,MagDipID,      Ionogram%MagDip)   )
CALL CHECK( nf90_put_var(ncid,GyroFreqID,    Ionogram%GyroFreq) )
! Range axis Info
CALL CHECK( nf90_put_var(ncid,PRIID,         Ionogram%PRI)       )
CALL CHECK( nf90_put_var(ncid,RangeGateOffsetID, Ionogram%RangeGateOffset) )
CALL CHECK( nf90_put_var(ncid,GateCountID,   Ionogram%GateCount) )
CALL CHECK( nf90_put_var(ncid,GateStartID,   Ionogram%GateStart) )
CALL CHECK( nf90_put_var(ncid,GateEndID,     Ionogram%GateEnd)   )
CALL CHECK( nf90_put_var(ncid,GateStepID,    Ionogram%GateStep)  )
CALL CHECK( nf90_put_var(ncid,Range0ID,      Ionogram%RANGE0) )
CALL CHECK( nf90_put_var(ncid,RangeValID,    Ionogram%Range(1:NRANGE)) )
!
! Frequency Axis Info
CALL CHECK( nf90_put_var(ncid,FreqStartID,    Ionogram%FreqStart) )
CALL CHECK( nf90_put_var(ncid,FreqEndID,      Ionogram%FreqEnd)   )
CALL CHECK( nf90_put_var(ncid,FreqStepsID,    Ionogram%FreqSteps) )
CALL CHECK( nf90_put_var(ncid,TuneTypeID,     Ionogram%TuneType)  )
CALL CHECK( nf90_put_var(ncid,LinearStepID,   Ionogram%LinearStep))
CALL CHECK( nf90_put_var(ncid,LogStepID,      Ionogram%LogStep)   )
CALL CHECK( nf90_put_var(ncid,FrequencyValID, Ionogram%Frequency(1:NFREQ)) )
!
! Measurement Time
CALL CHECK( nf90_put_var(ncid,TimeValID, Ionogram%Time(1:NFREQ)) )
!
! Transmitter Drive Level
CALL CHECK( nf90_put_var(ncid,TxDriveID, Ionogram%TxDrive(1:NFREQ)) )
!
! Normalization Factor
CALL CHECK( nf90_put_var(ncid,NumAveID, Ionogram%NumAve(1:NFREQ)) )

! Load in the SCT
CALL CHECK( nf90_put_var(ncid,SCTID,                 ByteSCT(1:Ionogram%SCT%sounding_table_size)) )
CALL CHECK( nf90_put_var(ncid,MagicID,               Ionogram%SCT%magic ) )
CALL CHECK( nf90_put_var(ncid,SCTversionID,          Ionogram%SCT%struct_version ) )
CALL CHECK( nf90_put_var(ncid,SCTReadmeID,           Ionogram%SCT%readme ) )
CALL CHECK( nf90_put_var(ncid,DecimationMethodID,    Ionogram%SCT%decimation_method ) )
CALL CHECK( nf90_put_var(ncid,DecimationThresholdID, Ionogram%SCT%decimation_threshold ) )
CALL CHECK( nf90_put_var(ncid,SCTUserID,             Ionogram%SCT%user ) )
CALL CHECK( nf90_put_var(ncid,StationFileIdID,              Ionogram%SCT%station%file_id) )
CALL CHECK( nf90_put_var(ncid,RxNameID,              Ionogram%SCT%station%rx_name) )
CALL CHECK( nf90_put_var(ncid,RxLatitudeID,          Ionogram%SCT%station%rx_latitude) )
CALL CHECK( nf90_put_var(ncid,RxLongitudeID,         Ionogram%SCT%station%rx_longitude) )
CALL CHECK( nf90_put_var(ncid,RxAltitudeID,          Ionogram%SCT%station%rx_altitude) )
CALL CHECK( nf90_put_var(ncid,RxCountID,             Ionogram%SCT%station%rx_count) )
CALL CHECK( nf90_put_var(ncid,RxAntennaTypeID,       Ionogram%SCT%station%rx_antenna_type) )
CALL CHECK( nf90_put_var(ncid,RxPositionID,          Ionogram%SCT%station%rx_position) )
CALL CHECK( nf90_put_var(ncid,RxDirectionID,         Ionogram%SCT%station%rx_direction) )
CALL CHECK( nf90_put_var(ncid,RxHeightID,            Ionogram%SCT%station%rx_height) )
CALL CHECK( nf90_put_var(ncid,RxCableLengthID,       Ionogram%SCT%station%rx_cable_length) )
! Attenuation
CALL CHECK( nf90_put_var(ncid,FrontendAttenID,       Ionogram%SCT%station%frontend_atten) )
! Transmitter
CALL CHECK( nf90_put_var(ncid,TxNameID,              Ionogram%SCT%station%tx_name) )
CALL CHECK( nf90_put_var(ncid,TxLatitudeID,          Ionogram%SCT%station%tx_latitude) )
CALL CHECK( nf90_put_var(ncid,TxLongitudeID,         Ionogram%SCT%station%tx_longitude) )
CALL CHECK( nf90_put_var(ncid,TxAltitudeID,          Ionogram%SCT%station%tx_altitude) )
CALL CHECK( nf90_put_var(ncid,TxAntennaTypeID,       Ionogram%SCT%station%tx_antenna_type) )
CALL CHECK( nf90_put_var(ncid,TxVectorID,            Ionogram%SCT%station%tx_vector) )
CALL CHECK( nf90_put_var(ncid,TxHeightID,            Ionogram%SCT%station%tx_height) )
CALL CHECK( nf90_put_var(ncid,TxCableLengthID,       Ionogram%SCT%station%tx_cable_length) )
! Drive Bands
CALL CHECK( nf90_put_var(ncid,DriveBandCountID,      Ionogram%SCT%station%drive_band_count) )
CALL CHECK( nf90_put_var(ncid,DriveBandBoundsID,     Ionogram%SCT%station%drive_band_bounds) )
CALL CHECK( nf90_put_var(ncid,DriveBandAttenID,      Ionogram%SCT%station%drive_band_atten) )
CALL CHECK( nf90_put_var(ncid,RfControlID,           Ionogram%SCT%station%rf_control) )
CALL CHECK( nf90_put_var(ncid,RefTypeID,             Ionogram%SCT%station%ref_type) )
CALL CHECK( nf90_put_var(ncid,ClockTypeID,           Ionogram%SCT%station%clock_type) )
CALL CHECK( nf90_put_var(ncid,StationUserID,         Ionogram%SCT%station%user) )
!
! Timing
CALL CHECK( nf90_put_var(ncid,TimingFileIdID,      Ionogram%SCT%timing%file_id) )
!CALL CHECK( nf90_put_var(ncid,PriID,              Ionogram%SCT%timing%pri) )   ! Redundant
CALL CHECK( nf90_put_var(ncid,PriCountID,          Ionogram%SCT%timing%pri_count) )
CALL CHECK( nf90_put_var(ncid,IonogramCountID,     Ionogram%SCT%timing%ionogram_count) )
CALL CHECK( nf90_put_var(ncid,HoldoffID,           Ionogram%SCT%timing%holdoff) )
! Redundant, encoded earlier
!CALL CHECK( nf90_put_var(ncid,RangeGateOffsetID,  Ionogram%SCT%timing%range_gate_offset) )
!CALL CHECK( nf90_put_var(ncid,GateCountID,        Ionogram%SCT%timing%gate_count) )
!CALL CHECK( nf90_put_var(ncid,GateStartID,        Ionogram%SCT%timing%gate_start) )
!CALL CHECK( nf90_put_var(ncid,GateEndID,          Ionogram%SCT%timing%gate_end) )
!CALL CHECK( nf90_put_var(ncid,GateStepID,         Ionogram%SCT%timing%gate_step) )
CALL CHECK( nf90_put_var(ncid,DataStartID,         Ionogram%SCT%timing%data_start) )
CALL CHECK( nf90_put_var(ncid,DataWidthID,         Ionogram%SCT%timing%data_width) )
CALL CHECK( nf90_put_var(ncid,DataBaudCountID,     Ionogram%SCT%timing%data_baud_count) )
CALL CHECK( nf90_put_var(ncid,DataWaveFileIdID,    Ionogram%SCT%timing%data_wave_file) )
! netCDF cannot handle complex numbers.  Map into a 2 dimensional set of REAL()
DO I=1,1024
   IQARRAY(1,I)=REAL(Ionogram%SCT%timing%data_baud(I))
   IQARRAY(2,I)=AIMAG(Ionogram%SCT%timing%data_baud(I))
ENDDO
CALL CHECK( nf90_put_var(ncid,DataBaudID,          IQARRAY ) )
CALL CHECK( nf90_put_var(ncid,DataPairsID,         Ionogram%SCT%timing%data_pairs) )
CALL CHECK( nf90_put_var(ncid,CalStartID,          Ionogram%SCT%timing%cal_start) )
CALL CHECK( nf90_put_var(ncid,CalWidthID,          Ionogram%SCT%timing%cal_width) )
CALL CHECK( nf90_put_var(ncid,CalBaudCountID,      Ionogram%SCT%timing%cal_baud_count) )
CALL CHECK( nf90_put_var(ncid,CalWaveFileIdID,     Ionogram%SCT%timing%cal_wave_file) )
! netCDF cannot handle complex numbers.  Map into a 2 dimensional set of REAL()
DO I=1,1024
   IQARRAY(1,I)=REAL(Ionogram%SCT%timing%cal_baud(I))
   IQARRAY(2,I)=AIMAG(Ionogram%SCT%timing%cal_baud(I))
ENDDO
CALL CHECK( nf90_put_var(ncid,CalBaudID,           IQARRAY) )
CALL CHECK( nf90_put_var(ncid,CalPairsID,          Ionogram%SCT%timing%cal_pairs) )
CALL CHECK( nf90_put_var(ncid,TimingUserID,        Ionogram%SCT%timing%user) )
!
! SCT%frequency
CALL CHECK( nf90_put_var(ncid,FrequencyFileIdID,         Ionogram%SCT%frequency%file_id ) )
! Base Start defined earlier
! Base End defined earlier
CALL CHECK( nf90_put_var(ncid,BaseStepsID,          Ionogram%SCT%frequency%base_steps ) )
! Tune Type defined earlier
! Freq Count defined earlier
! Linear Step defined earlier
! Log Step defined earlier
CALL CHECK( nf90_put_var(ncid,BaseTableID,          Ionogram%SCT%frequency%base_table ) )
CALL CHECK( nf90_put_var(ncid,FrequencyTableIdID,   Ionogram%SCT%frequency%freq_table_id ) )
CALL CHECK( nf90_put_var(ncid,TuneStepsID,          Ionogram%SCT%frequency%tune_steps ) )
CALL CHECK( nf90_put_var(ncid,PulseCountID,         Ionogram%SCT%frequency%pulse_count ) )
CALL CHECK( nf90_put_var(ncid,PulsePatternID,       Ionogram%SCT%frequency%pulse_pattern ) )
CALL CHECK( nf90_put_var(ncid,PulseOffsetID,        Ionogram%SCT%frequency%pulse_offset ) )
CALL CHECK( nf90_put_var(ncid,RampStepsID,          Ionogram%SCT%frequency%ramp_steps) )
CALL CHECK( nf90_put_var(ncid,RampRepeatsID,        Ionogram%SCT%frequency%ramp_repeats ) )
CALL CHECK( nf90_put_var(ncid,DriveTableID,         Ionogram%SCT%frequency%drive_table ) )
CALL CHECK( nf90_put_var(ncid,FrequencyUserID,      Ionogram%SCT%frequency%user ) )
!
! SCT%Receiver
CALL CHECK( nf90_put_var(ncid,ReceiverFileIdID,    Ionogram%SCT%receiver%file_id ) )
CALL CHECK( nf90_put_var(ncid,RxChanID,            Ionogram%SCT%receiver%rx_chan ) )
CALL CHECK( nf90_put_var(ncid,RxMapID,             Ionogram%SCT%receiver%rx_map) )
CALL CHECK( nf90_put_var(ncid,WordFormatID,        Ionogram%SCT%receiver%word_format ) )
CALL CHECK( nf90_put_var(ncid,RxCic2DecID,         Ionogram%SCT%receiver%cic2_dec ) )
CALL CHECK( nf90_put_var(ncid,RxCic2InterpID,      Ionogram%SCT%receiver%cic2_interp ) )
CALL CHECK( nf90_put_var(ncid,RxCic2ScaleID,       Ionogram%SCT%receiver%cic2_scale ) )
CALL CHECK( nf90_put_var(ncid,RxCic5DecID,         Ionogram%SCT%receiver%cic5_dec ) )
CALL CHECK( nf90_put_var(ncid,RxCic5ScaleID,       Ionogram%SCT%receiver%cic5_scale ) )
CALL CHECK( nf90_put_var(ncid,RxRcf_TypeID,        Ionogram%SCT%receiver%rcf_type ) )
CALL CHECK( nf90_put_var(ncid,RxRcfDecID,          Ionogram%SCT%receiver%rcf_dec ) )
CALL CHECK( nf90_put_var(ncid,RxRcfTapsID,         Ionogram%SCT%receiver%rcf_taps ) )
CALL CHECK( nf90_put_var(ncid,RxCoefficientsID,    Ionogram%SCT%receiver%coefficients ) )
CALL CHECK( nf90_put_var(ncid,RxAnalogDelayID,     Ionogram%SCT%receiver%analog_delay ) )
CALL CHECK( nf90_put_var(ncid,ReceiverUserID,      Ionogram%SCT%receiver%user ) )
!
! SCT%exciter
CALL CHECK( nf90_put_var(ncid,ExciterFileIdID,     Ionogram%SCT%exciter%file_id ) )
CALL CHECK( nf90_put_var(ncid,ExCic2ScaleID,       Ionogram%SCT%exciter%cic_scale ) )
CALL CHECK( nf90_put_var(ncid,ExCic2DecID,         Ionogram%SCT%exciter%cic2_dec ) )
CALL CHECK( nf90_put_var(ncid,ExCic2InterpID,      Ionogram%SCT%exciter%cic2_interp ) )
CALL CHECK( nf90_put_var(ncid,ExCic5InterpID,      Ionogram%SCT%exciter%cic5_interp ) )
CALL CHECK( nf90_put_var(ncid,ExRcfTypeID,         Ionogram%SCT%exciter%rcf_type ) )
CALL CHECK( nf90_put_var(ncid,ExRcfTapsID,         Ionogram%SCT%exciter%rcf_taps ) )
CALL CHECK( nf90_put_var(ncid,ExRcfTapsPhaseID,    Ionogram%SCT%exciter%rcf_taps_phase ) )
CALL CHECK( nf90_put_var(ncid,ExCoefficientsID,    Ionogram%SCT%exciter%coefficients ) )
CALL CHECK( nf90_put_var(ncid,ExAnalogDelayID,     Ionogram%SCT%exciter%analog_delay ) )
CALL CHECK( nf90_put_var(ncid,ExciterUserID,       Ionogram%SCT%exciter%user ) )
! SCT%monitor
CALL CHECK( nf90_put_var(ncid,BalunCurrentsID,     Ionogram%SCT%monitor%balun_currents ) )
CALL CHECK( nf90_put_var(ncid,BalunStatusID,       Ionogram%SCT%monitor%balun_status ) )
CALL CHECK( nf90_put_var(ncid,FrontendStatusID,    Ionogram%SCT%monitor%front_end_status ) )
CALL CHECK( nf90_put_var(ncid,ReceiverStatusID,    Ionogram%SCT%monitor%receiver_status ) )
CALL CHECK( nf90_put_var(ncid,ExciterStatusID,     Ionogram%SCT%monitor%exciter_status ) )
CALL CHECK( nf90_put_var(ncid,MonitorUserID,       Ionogram%SCT%monitor%user ) )

!
! Load the optional array flags
CALL CHECK( nf90_put_var(ncid,HasTotalPowerID,  Ionogram%HasTotalPower) )
CALL CHECK( nf90_put_var(ncid,HasOModePowerID,  Ionogram%HasOModePower) )
CALL CHECK( nf90_put_var(ncid,HasXModePowerID,  Ionogram%HasXmodePower) )
CALL CHECK( nf90_put_var(ncid,HasVlosID,        Ionogram%HasVLoS)       )
CALL CHECK( nf90_put_var(ncid,HasDopplerID,     Ionogram%HasDoppler)    )
CALL CHECK( nf90_put_var(ncid,HasSPGRID,        Ionogram%HasSPGR)       )
CALL CHECK( nf90_put_var(ncid,HasZenithID,      Ionogram%HasZenith)     )
CALL CHECK( nf90_put_var(ncid,HasAzimuthID,     Ionogram%HasAzimuth)    )
CALL CHECK( nf90_put_var(ncid,HasCoherenceID,   Ionogram%HasCoherence)  )
!
!
IF (Ionogram%HasTotalPower.NE.0) THEN
   CALL CHECK( nf90_put_var(ncid,TotalPowerID,  Ionogram%TPower(1:NRANGE,1:NFREQ)) )
   CALL CHECK( nf90_put_var(ncid,TotalNoiseID,  Ionogram%TNoiseLevel(1:NFREQ)    ) )
ENDIF 
IF (Ionogram%HasOModePower.NE.0) THEN
   CALL CHECK( nf90_put_var(ncid,OModePowerID,  Ionogram%OPower(1:NRANGE,1:NFREQ)) )
   CALL CHECK( nf90_put_var(ncid,OModeNoiseID,  Ionogram%ONoiseLevel(1:NFREQ)    ) )
ENDIF 
IF (Ionogram%HasXModePower.NE.0) THEN
   CALL CHECK( nf90_put_var(ncid,XModePowerID,  Ionogram%XPower(1:NRANGE,1:NFREQ)) )
   CALL CHECK( nf90_put_var(ncid,XModeNoiseID,  Ionogram%XNoiseLevel(1:NFREQ)    ) )
ENDIF 
!
! Close the file.
CALL CHECK( nf90_close(ncid) )

!
!
RETURN
!
!
CONTAINS

SUBROUTINE CHECK(STATUS)
!
! Writes NetCDF errors to standard error 
!
INTEGER,INTENT(IN):: STATUS

IF ( STATUS.NE.NF90_NOERR) WRITE(0,*) "write_netCDF3 -- ERROR -- ", trim(nf90_strerror(STATUS))
RETURN
END SUBROUTINE CHECK 

END 
